@@ -412,12 +412,7 @@ namespace msXpSlibmass
 
 			// Finally, do the work.
 
-			QString *text = thisTrace()->asText(rangeStart, rangeEnd);
-
-			QString result = *text;
-			delete text;
-
-			return result;
+			return thisTrace()->asText(rangeStart, rangeEnd);
 		}
 
 
