@@ -1,34 +1,35 @@
-/*  BEGIN software license
+/* BEGIN software license
  *
- *  msXpertSuite - mass spectrometry software suite
- *  -----------------------------------------------
- *  Copyright(C) 2009, 2017 Filippo Rusconi
+ * msXpertSuite - mass spectrometry software suite
+ * -----------------------------------------------
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
- *  http://www.msxpertsuite.org
+ * http://www.msxpertsuite.org
  *
- *  This file is part of the msXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- *  The msXpertSuite project is the successor of the massXpert project. This
- *  project now includes various independent modules:
- *  
- *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
- *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * The msXpertSuite project is the successor of the massXpert project. This
+ * project now includes various independent modules:
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
  * END software license
-*/
+ */
+
 
 
 
@@ -67,7 +68,7 @@ namespace msXpSmassXpert
 			const QString &avg)
 		:
 			AbstractMainTaskWindow{parent,
-				"CalculatorWnd", 
+				"CalculatorWnd",
 				"massXpert: calculator"}
 	{
 		if(polChemDefFilePath.isEmpty())
@@ -306,7 +307,7 @@ namespace msXpSmassXpert
 				new CalculatorRecorderDlg(static_cast<QWidget *>(this),
 						mp_parentWnd->configSettingsFilePath());
 
-			mpa_chemPadDlg = 
+			mpa_chemPadDlg =
 				new CalculatorChemPadDlg(this);
 
 			if (!m_polChemDef.renderXmlPolChemDefFile())
@@ -438,7 +439,7 @@ namespace msXpSmassXpert
 
 				const ConfigSettings *configSettings = mp_parentWnd->configSettings();
 				const ConfigSetting *configSetting = configSettings->value("dataDir", msXpS::UserType::USER_TYPE_USER);
-				
+
 				filePath = configSetting->m_value.toString() + "/chemPad.conf";
 			}
 			else
@@ -1496,7 +1497,7 @@ namespace msXpSmassXpert
 						tr("massXpert - Calculator"),
 						tr("No atom list is available"),
 						QMessageBox::Ok);
-				return QString("");;
+				return QString("");
 			}
 
 			QString text = m_ui.formulaComboBox->currentText();
