@@ -91,7 +91,7 @@ namespace msXpSmineXpert
 */
 	AbstractPlotWidget::AbstractPlotWidget(QWidget *parent,
 			const QString &name, const QString &desc,
-			MassSpecDataSet *massSpecDataSet, const QString &fileName,
+			const MassSpecDataSet *massSpecDataSet, const QString &fileName,
 			bool isMultiGraph)
 		:
 			QCustomPlot{parent},
@@ -102,9 +102,9 @@ namespace msXpSmineXpert
 		m_fileName{fileName},
 		m_isMultiGraph{isMultiGraph}
 	{
-		//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-		//<< "Creating new plot widget:" << this
-		//<< "with parent window:" << parent;
+		qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			<< "Creating new plot widget:" << this
+			<< "with parent window:" << parent;
 
 		if(parent == Q_NULLPTR)
 			qFatal("Fatal error at %s@%d -- %s(). "
@@ -117,6 +117,7 @@ namespace msXpSmineXpert
 
 		setObjectName("plotWidget");
 
+#if 0
 		if(fileName.isEmpty())
 			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
 				<< "The file name passed to the plot widget constructor is empty";
@@ -139,6 +140,7 @@ namespace msXpSmineXpert
 						<< "The file name passed as parameter:" << fileName;
 			}
 		}
+#endif
 
 		show();
 	}
@@ -1056,7 +1058,7 @@ namespace msXpSmineXpert
 						__FILE__, __LINE__, __FUNCTION__);
 
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "The plot widget's m_fileName:" << m_fileName;
+			//<< "The plot widget's m_fileName:" << m_fileName;
 
 			p_massDataSlicerWnd->initialize(fileInfo.absoluteFilePath(),
 					start, end, localHistory);
@@ -1413,6 +1415,30 @@ namespace msXpSmineXpert
 		}
 
 
+	//! Set the last TIC intensity value.
+	void
+		AbstractPlotWidget::setLastTicIntensity(double value)
+		{
+			m_lastTicIntensity = value;
+		}
+
+
+
+	/*/js/
+	 * <PlotWidget>.lastTicIntensity()
+	 *
+	 * Return the last TIC intensity value that was computed.
+	 */
+
+	//! Return the last TIC intensity value that was computed.
+	double
+		AbstractPlotWidget::lastTicIntensity(void)
+		{
+			return m_lastTicIntensity;
+		}
+
+
+
 	/*/js/
 	 * <PlotWidget>.trace()
 	 *
