@@ -56,7 +56,7 @@ namespace msXpSmineXpert
 	 * form of object variable names colorMapPlotWidget[index], with [index]
 	 * being 0 for the first object created and being incremented each time a new
 	 * ColorMapPlotWidget is created.</comment>
-	*/
+	 */
 
 
 	//! Construct a ColorMapPlotWidget instance.
@@ -83,7 +83,7 @@ namespace msXpSmineXpert
 	ColorMapPlotWidget::ColorMapPlotWidget(QWidget *parent,
 			const QString &name,
 			const QString &desc,
-			MassSpecDataSet *massSpecDataSet,
+			const MassSpecDataSet *massSpecDataSet,
 			const QString &fileName,
 			bool isMultiGraph)
 		: AbstractPlotWidget{parent, name,
@@ -460,7 +460,7 @@ namespace msXpSmineXpert
 	 *
 	 * The TIC intensity value is returned
 	 */
-	double
+	void
 		ColorMapPlotWidget::integrateToTicIntensity(double dtRangeStart, double dtRangeEnd,
 				double mzRangeStart, double mzRangeEnd)
 		{
@@ -476,37 +476,32 @@ namespace msXpSmineXpert
 			// Aggreate the new item to the local history copy we made.
 			localHistory.appendHistoryItem(histItem);
 
-			ColorMapWnd *parentWnd = static_cast<ColorMapWnd *>(mp_parentWnd);
-
-
 			// Capture immediately the text that is located in the status bar
 			// because if the computation is long that text will have disappeared
 			// and we won't be able to show it in the TIC int text.
 
+			QMainWindow *parentWnd = static_cast<QMainWindow *>(mp_parentWnd);
 			QString currentMessage = parentWnd->statusBar()->currentMessage();
 
-			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
-
-			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
-
-			integrator.integrateToTicIntensity();
-
-			m_lastI = integrator.ticIntensity();
-
-			QApplication::restoreOverrideCursor();
-
 			if(currentMessage.isEmpty())
-				parentWnd->statusBar()->showMessage(QString("dt range [%1-%2] ; m/z range [%3-%4]: TIC I = %5")
-						.arg(dtRangeStart, 0, 'f', 3)
-						.arg(dtRangeEnd, 0, 'f', 3)
-						.arg(mzRangeStart, 0, 'f', 3)
-						.arg(mzRangeEnd, 0, 'f', 3)
-						.arg(m_lastI, 0, 'g', 3));
+				currentMessage = QString("dt range [%1-%2] ; m/z range [%3-%4]")
+					.arg(dtRangeStart, 0, 'f', 3)
+					.arg(dtRangeEnd, 0, 'f', 3)
+					.arg(mzRangeStart, 0, 'f', 3)
+					.arg(mzRangeEnd, 0, 'f', 3);
 			else
-				parentWnd->statusBar()->showMessage(currentMessage +
-						QString(" ; (Tic I = %1)").arg(m_lastI, 0, 'g', 3));
+				currentMessage +=
+					QString(" - dt range [%1-%2] ; m/z range [%3-%4]")
+					.arg(dtRangeStart, 0, 'f', 3)
+					.arg(dtRangeEnd, 0, 'f', 3)
+					.arg(mzRangeStart, 0, 'f', 3)
+					.arg(mzRangeEnd, 0, 'f', 3);
+
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "Emitting ticIntensitySignal";
+
+			emit ticIntensitySignal(mp_massSpecDataSet, currentMessage, localHistory);
 
-			return m_lastI;
 		}
 
 
