@@ -81,7 +81,7 @@ namespace msXpSmineXpert
 	DriftSpecPlotWidget::DriftSpecPlotWidget(QWidget *parent,
 			const QString &name,
 			const QString &desc,
-			MassSpecDataSet *massSpecDataSet,
+			const MassSpecDataSet *massSpecDataSet,
 			const QString &fileName,
 			bool isMultiGraph)
 		: AbstractPlotWidget{parent, name,
@@ -310,7 +310,7 @@ namespace msXpSmineXpert
 					}
 					if(curChar == 'I')
 					{
-						stanza += QString("%1").arg(m_lastI, 0, 'g', 3);
+						stanza += QString("%1").arg(m_lastTicIntensity, 0, 'g', 3);
 
 						prevChar = ' ';
 						continue;
@@ -489,14 +489,14 @@ namespace msXpSmineXpert
 	 */
 
 	//! Integrate data to a single TIC intensity value with drift time range [\p lower -- \p upper ].
-	double
+	void
 		DriftSpecPlotWidget::integrateToTicIntensity(double lower, double upper)
 		{
 			if(m_isMultiGraph)
 				// We cannot perform the action, because this plot widget has not mass
 				// spec data set pointer, it is a graph-only plot widget to display all
 				// the graphs overlaid.
-				return 0;
+				return;
 
 			// Get the pointer to the x-axis (key axis).
 
@@ -520,11 +520,11 @@ namespace msXpSmineXpert
 			m_keyRangeEnd = qSNaN();
 
 			// Also reset the other datum that might hold invalid values.
-			m_lastI = qSNaN();
+			m_lastTicIntensity = qSNaN();
 
 			if(rangeStart == rangeEnd)
 			{
-				return false;
+				return;
 			}
 
 			// Slot for sorting stuff.
@@ -547,19 +547,9 @@ namespace msXpSmineXpert
 			m_keyRangeStart = rangeStart;
 			m_keyRangeEnd = rangeEnd;
 
-			// Aggreate the new item to the history.
+			// Aggreate the new item to the local history copy we made.
 			localHistory.appendHistoryItem(histItem);
 
-			DriftSpecWnd *parentWnd = static_cast<DriftSpecWnd *>(mp_parentWnd);
-
-			// Capture immediately the text that is located in the status bar
-			// because if the computation is long that text will have disappeared
-			// and we won't be able to show it in the TIC int text.
-
-			QString currentMessage = parentWnd->statusBar()->currentMessage();
-
-			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
-
 			// Sanity check. It is not possible that this plot widget is not
 			// multi-graph and that at the same time, the mass spec data set pointer
 			// is nullptr.
@@ -570,27 +560,26 @@ namespace msXpSmineXpert
 						"Program aborted.",
 						__FILE__, __LINE__, __FUNCTION__);
 
-			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
+			// Capture immediately the text that is located in the status bar
+			// because if the computation is long that text will have disappeared
+			// and we won't be able to show it in the TIC int text.
 
-			integrator.integrateToTicIntensity();
-
-			m_lastI = integrator.ticIntensity();
-
-			QApplication::restoreOverrideCursor();
+			QMainWindow *parentWnd = static_cast<QMainWindow *>(mp_parentWnd);
+			QString currentMessage = parentWnd->statusBar()->currentMessage();
 
 			if(currentMessage.isEmpty())
-				parentWnd->statusBar()->showMessage(QString("range [%1-%2]: TIC I = %3")
-						.arg(m_keyRangeStart, 0, 'f', 3)
-						.arg(m_keyRangeEnd, 0, 'f', 3)
-						.arg(m_lastI, 0, 'g', 3));
+				currentMessage = QString("range [%1-%2]")
+					.arg(m_keyRangeStart, 0, 'f', 3)
+					.arg(m_keyRangeEnd, 0, 'f', 3);
 			else
-				parentWnd->statusBar()->showMessage(currentMessage +
-						QString(" ; range [%1-%2]: TIC I = %3")
-						.arg(m_keyRangeStart, 0, 'g', 3)
-						.arg(m_keyRangeEnd, 0, 'g', 3)
-						.arg(m_lastI, 0, 'g', 3));
+				currentMessage += QString(" ; range [%1-%2]")
+					.arg(m_keyRangeStart, 0, 'f', 3)
+					.arg(m_keyRangeEnd, 0, 'f', 3);
 
-			return m_lastI;
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "Emitting ticIntensitySignal";
+
+			emit ticIntensitySignal(mp_massSpecDataSet, currentMessage, localHistory);
 		}
 
 
