@@ -672,19 +672,27 @@ namespace msXpSmineXpert
 				m_colorList.takeFirst();
 			}
 
-			// Before computing the TIC and plotting it, let the window know what
-			// color we wish for the plot.
-			mp_ticChromWnd->setWishedColor(*useColor);
-
 			//qDebug() << __FILE__ << __LINE__ << "Calculating the TIC chromatogram...";
+			// Now compute the TIC and plot it. The function returns the plot widget
+			// that displays the chromatogram for this mass spec data set.
 
 			statusBarMessage("Calculating the TIC chromatogram...");
 			logConsoleMessage("Calculating the TIC chromatogram...\n");
 
-			// Now compute the TIC and plot it. The function returns the plot widget
-			// that displays the chromatogram for this mass spec data set.
+			mp_ticChromWnd->initialTic(p_massSpecDataSet, *useColor);
 
-			AbstractPlotWidget *widget = mp_ticChromWnd->initialTic(p_massSpecDataSet);
+			// The initialTic function from TicChromWnd will signal
+			// "initialTicDoneSignal" to finalize the operation.
+		}
+
+	void
+		MainWindow::initialTicDone(AbstractPlotWidget *widget,
+				const MassSpecDataSet *massSpecDataSet, QColor color)
+		{
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
+			//<< "with color" << color
+			//<< "with integrator:" << integrator
+			//<< "and widget:" << widget;
 
 			if(widget == Q_NULLPTR)
 			{
@@ -696,8 +704,6 @@ namespace msXpSmineXpert
 				msgBox.setStandardButtons(QMessageBox::Ok);
 				msgBox.exec();
 
-				delete p_massSpecDataSet;
-
 				return;
 			}
 
@@ -711,25 +717,120 @@ namespace msXpSmineXpert
 
 			statusBarMessage("Done loading file.");
 			QTimer::singleShot(3000, this, [=]() {
-					this->updateFeedback("", 0);
-					this->mp_statusBarProgressBar->setVisible(false);
+					this->updateFeedback("", 0, false /* setVisible */, LOG_TO_STATUS_BAR);
 					});
 
 			logConsoleMessage("Done loading file.\n");
 
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "Going to add the tic chrom plot widget to the open spectra dialog.";
+
 			// Add a new item to the open spectrum dialog window widget list such
 			// that we'll know which files are open. Note that the function below
 			// will create a mapping between the list widget item and the tic chrom plot
 			// widget that is set to be the parent of p_massSpecDataSet.
 			QListWidgetItem *item =
-				mp_openSpectraDlg->addOpenSpectrum(p_massSpecDataSet, *useColor);
+				mp_openSpectraDlg->addOpenSpectrum(massSpecDataSet, color);
+
+			// Now make sure that the open spectra dialog's list widget item is
+			// selected by default.
+
+			mp_openSpectraDlg->selectPlotWidget(widget);
 
 			// The root relation is when the relation has no origin plot widget but
 			// has a target plot widget. This is how a relation is recognized to
 			// describe a root plot widget.
 			m_dataPlotWidgetRelationer.newRelation(
-					p_massSpecDataSet, Q_NULLPTR /*origin plot widget */,
+					massSpecDataSet, Q_NULLPTR /*origin plot widget */,
 					widget /*target plot widget */, item);
+
+			if(massSpecDataSet->isMobilityExperiment())
+			{
+
+				//////////////////////////// COLOR MAP WND //////////////////////////////
+				//////////////////////////// COLOR MAP WND //////////////////////////////
+
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+					<< "Now chaining on to the initial color map stuff";
+
+				// At this time, we now can compute the initial color map, thus generating
+				// a new plot widget that we will associate to the tic chrom plot widget.
+
+				statusBarMessage("Calculating the Color map...");
+				logConsoleMessage("Calculating the Color map...\n");
+
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+					<< "going to call mp_colorMapWnd->initialColorMap;"
+					<< "with massSpecDataSet:" << massSpecDataSet
+					<< "and filename:" << massSpecDataSet->fileName();
+
+				mp_colorMapWnd->initialColorMap(massSpecDataSet, widget, color);
+
+				// The initialColorMap function from ColorMapWnd will signal
+				// initialColorMapDone to finalize the operation.
+			}
+
+			// Finally inform the user of the MzIntegrationParams stuff.
+			// But only show the informative dialog if there are multiple spectra in the
+			// data set. Otherwise it does not make sense.
+
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "checking if we need to display the mz integ params help dialog window";
+
+			if(massSpecDataSet->size() > 1)
+				showMzIntegrationParamsHelp(massSpecDataSet->statistics().m_smallestStepMedian);
+		}
+
+
+	void
+		MainWindow::initialColorMapDone(AbstractPlotWidget *widget,
+				AbstractPlotWidget *originWidget, const MassSpecDataSet *massSpecDataSet, QColor color)
+		{
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
+				<< "current thread id:" << QThread::currentThreadId();
+
+			if(widget == Q_NULLPTR)
+			{
+				QMessageBox msgBox;
+				msgBox.setText(
+						"The program failed to compute an initial TIC chromatogram. Please,"
+						" ensure that the file being loaded is correct.");
+
+				msgBox.setStandardButtons(QMessageBox::Ok);
+				msgBox.exec();
+
+				return;
+			}
+
+			// Make sure we show it on the fore for the user to see it.
+			showColorMapWnd();
+
+			// The colormap is considered to be a descendant from the TIC:
+
+			m_dataPlotWidgetRelationer.newRelation(
+					massSpecDataSet, originWidget /*origin plot widget */,
+					widget /*target plot widget */,
+					Q_NULLPTR /* openspectradlglistwidgetitem */);
+
+			// Make sure the origin widget (the matching TicChromPlotWidget) is focused.
+			originWidget->setFocus();
+
+			// At this point, the mainwindow should show a message telling that the
+			// file was successfully loaded, since loading a file is actually two
+			// things in sequence:
+			// 1. Opening the file and loading the data
+			// 2. Calculating a TIC chromatogram on the basis of the loaded data.
+
+			statusBarMessage("Done loading file.");
+			QTimer::singleShot(3000, this, [=]() {
+					this->updateFeedback("", 0, false /* setVisible */, LOG_TO_STATUS_BAR);
+					});
+
+			logConsoleMessage("Done loading file.\n");
+
+			// Finally inform the user of the MzIntegrationParams stuff.
+			// But only show the informative dialog if there are multiple spectra in the
+			// data set. Otherwise it does not make sense.
 		}
 
 
@@ -884,11 +985,24 @@ namespace msXpSmineXpert
 
 			MassSpecDataFileLoaderSqlite3 loader(fileName);
 
-			if(!loader.m_sqlite3Handler.initializeDbForRead(fileName))
-			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to initialize the database for read. Returning.";
+			//! Handler of SQLite3-based mass data.
+			//This loader loads data from a SQLite3-based mass spectrometry format and
+			//uses the features of the MassSpecSqlite3Handler class that is required
+			//to craft SQL-based statements to extract data from the database file.
 
+			MassSpecSqlite3Handler sqlite3Handler;
+
+			// And now, make sure the member database, the source database is fine.
+
+			QString connectionName = QString("%1/%2").arg(fileName).arg(msXpS::pointerAsString(this));
+			QSqlDatabase database = QSqlDatabase::addDatabase("QSQLITE", connectionName);
+			database.setDatabaseName(fileName);
+
+			// Now make sure that the metadata from the database are read and stored
+			// in the sqlite3 handler:
+			if(!sqlite3Handler.initializeDbForRead(database, true /* readMetaData */))
+			{
+				logConsoleMessage("Failed to initialize the database for reading.");
 				return;
 			}
 
@@ -910,7 +1024,7 @@ namespace msXpSmineXpert
 
 			double start = omp_get_wtime();
 
-			int readSpectra = loader.loadData(p_massSpecDataSet);
+			int readSpectra = loader.loadData(database, sqlite3Handler, p_massSpecDataSet);
 
 			if(!p_massSpecDataSet->isStreamed() && readSpectra <= 0)
 			{
@@ -984,7 +1098,7 @@ namespace msXpSmineXpert
 
 			double start = omp_get_wtime();
 
-			loader.loadData(p_massSpecDataSet);
+			loader.loadDataToMassSpecDataSet(p_massSpecDataSet);
 
 			// We do store mass spectra in the mass spec data set only if we are not
 			// streaming or if we are streaming AND we are loading ion mobility mass
@@ -1092,9 +1206,12 @@ namespace msXpSmineXpert
 
 			double start = omp_get_wtime();
 
-			setupFeedback(msg, 1 /* first value */,
-					spectrumCount /*last value */);
+			m_progressFeedbackStartValue = 0;
+			m_progressFeedbackEndValue = spectrumCount;
 
+			updateFeedback(msg, 1, true /* setVisible */,
+					LogType::LOG_TO_BOTH,
+					m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 			// This data set will be reparented when we provide it to the handling
 			// widget (window or plot widget or whatever QObject).
@@ -1204,8 +1321,12 @@ namespace msXpSmineXpert
 
 			QApplication::processEvents();
 
-			setupFeedback(msg, 1 /* first value */,
-					spectrumCount /*last value */);
+			m_progressFeedbackStartValue = 0;
+			m_progressFeedbackEndValue = spectrumCount;
+
+			updateFeedback(msg, 1, true /* setVisible */,
+					LogType::LOG_TO_BOTH,
+					m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 			double start = omp_get_wtime();
 
@@ -1317,8 +1438,12 @@ namespace msXpSmineXpert
 
 			QApplication::processEvents();
 
-			setupFeedback(msg, 1 /* first value */,
-					spectrumCount /*last value */);
+			m_progressFeedbackStartValue = 0;
+			m_progressFeedbackEndValue = spectrumCount;
+
+			updateFeedback(msg, 1, true /* setVisible */,
+					LogType::LOG_TO_BOTH,
+					m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 			double start = omp_get_wtime();
 
@@ -1484,17 +1609,8 @@ namespace msXpSmineXpert
 			// Connect the loader to this window so that we can display the reader log
 			// messages:
 
-			connect(loader, &MassSpecDataFileLoader::setupFeedbackSignal,
-					this, &MainWindow::setupFeedback);
-
-			connect(loader, &MassSpecDataFileLoader::dataLoadMessageSignal,
-					this, &MainWindow::dataLoadMessage);
-
-			// Also, make sure we get the signal that informs us on the spectrum
-			// reading progression:
-
-			connect(loader, &MassSpecDataFileLoader::dataLoadProgressSignal,
-					this, &MainWindow::statusBarProgress);
+			connect(loader, &MassSpecDataFileLoader::updateFeedbackSignal,
+					this, &MainWindow::updateFeedback);
 
 			connect(this, &MainWindow::cancelOperationSignal, loader,
 					&MassSpecDataFileLoader::cancelOperation);
@@ -1755,6 +1871,84 @@ namespace msXpSmineXpert
 		}
 
 
+	void
+		MainWindow::showMzIntegrationParamsHelp(double smallestStepMedian)
+		{
+			QSettings settings;
+
+			bool noShowHelp =	settings.value("MainWindow_nomoreShowMzIntegrationParamsHelp", false).toBool();
+
+			if(noShowHelp)
+				return;
+
+			QDialog *explanationDlg = new QDialog;
+			QVBoxLayout *verticalLayout;
+			QTextEdit *textEdit;
+			QCheckBox *doNotShowAgainCheckBox;
+			QPushButton *okPushButton;
+			if (explanationDlg->objectName().isEmpty())
+				explanationDlg->setObjectName(QStringLiteral("explanationDlg"));
+			explanationDlg->resize(319, 300);
+			verticalLayout = new QVBoxLayout(explanationDlg);
+			verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
+			textEdit = new QTextEdit(explanationDlg);
+			textEdit->setObjectName(QStringLiteral("textEdit"));
+			verticalLayout->addWidget(textEdit);
+
+			QString helpMsg = QString("When mass spectral data are loaded from file,\n"
+					"statistics are computed and are used to configure\n"
+					"the mass spectral integrations to a mass spectrum.\n"
+					"These statistics are shown in the console window. \n"
+					"\n"
+					"The last file loaded had a median value for the\n"
+					"smallest m/z delta of %1 m/z. This value is used \n"
+					"to configure the bin size. Please, check the m/z \n"
+					"integration parameters window. Note that mass spectral\n"
+					"integrations to a mass spectrum sometimes need some tweaking\n"
+					"of the integration parameters.\n\n"
+					"Please, refer to the user manual for a detailed explanation.").arg(smallestStepMedian, 0, 'f', 3);
+
+			textEdit->setPlainText(helpMsg);
+
+			doNotShowAgainCheckBox = new QCheckBox(explanationDlg);
+			doNotShowAgainCheckBox->setObjectName(QStringLiteral("doNotShowAgainCheckBox"));
+
+			verticalLayout->addWidget(doNotShowAgainCheckBox);
+
+			okPushButton = new QPushButton(explanationDlg);
+			okPushButton->setObjectName(QStringLiteral("okPushButton"));
+
+			verticalLayout->addWidget(okPushButton);
+
+			explanationDlg->setWindowTitle(QString("%1 - m/z integration parameters help").arg(m_moduleName));
+			okPushButton->setText("Ok");
+
+			connect(okPushButton,
+					&QPushButton::clicked,
+					explanationDlg,
+					&QDialog::close);
+
+			QMetaObject::connectSlotsByName(explanationDlg);
+			doNotShowAgainCheckBox->setText("Got it, do not show again");
+
+			connect(doNotShowAgainCheckBox,
+					&QCheckBox::clicked,
+					[=](const bool &isChecked)
+					{
+					qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+					QSettings settings;
+					settings.setValue("MainWindow_nomoreShowMzIntegrationParamsHelp", isChecked);
+					});
+
+			// Make sure the m/z integration parameters window is visible.
+			showMzIntegrationParamsWnd();
+
+			QTimer::singleShot(30000, explanationDlg, &QDialog::close);
+
+			explanationDlg->exec();
+		}
+
+
 	/*/js/
 	 * MainWindow.about()
 	 *
@@ -1820,6 +2014,52 @@ namespace msXpSmineXpert
 		}
 
 
+	//! Update the progress feedback using the \p msg string and the \p currentValue value.
+	void
+		MainWindow::updateFeedback(QString msg,
+				int currentValue, bool setVisible, int logType,
+				int startValue, int endValue)
+		{
+			//qDebug() << __FILE__ << __LINE__
+			//<< "Entering" << __FUNCTION__
+			//<< "with message: " << msg
+			//<< "currentValue:" << currentValue
+			//<< "set visible:" << setVisible
+			//<< "log type:" << logType
+			//<< "startValue:" << startValue
+			//<< "endValue:" << endValue;
+
+
+			if(logType & LogType::LOG_TO_CONSOLE)
+				logConsoleMessage(msg);
+
+			if(logType & LogType::LOG_TO_STATUS_BAR)
+			{
+				mp_statusBarLabel->setVisible(setVisible);
+				mp_statusBarCancelPushButton->setVisible(setVisible);
+				mp_statusBarProgressBar->setVisible(setVisible);
+
+				if(startValue != -1)
+					mp_statusBarProgressBar->setMinimum(startValue);
+				if(endValue != -1)
+					mp_statusBarProgressBar->setMaximum(endValue);
+
+				mp_statusBarProgressBar->setValue(currentValue);
+
+				mp_statusBarLabel->setText(msg);
+			}
+		}
+
+
+	//! Update the status bar message with the \p msg string.
+	void
+		MainWindow::updateStatusBar(QString msg)
+		{
+			statusBar()->showMessage(msg, 5000);
+		}
+
+
+
 	//! Log a message to various places specified with \p logType.
 	void
 		MainWindow::dataLoadMessage(QString message, int logType)
@@ -1996,33 +2236,6 @@ namespace msXpSmineXpert
 		}
 
 
-	//! Setup the feedback messaging system.
-	void
-		MainWindow::setupFeedback(QString msg, int startValue, int endValue,
-				int currentValue)
-		{
-			mp_statusBarProgressBar->setMinimum(startValue);
-			mp_statusBarProgressBar->setMaximum(endValue);
-
-			if(currentValue != -1)
-				mp_statusBarProgressBar->setValue(currentValue);
-
-			if(!msg.isEmpty())
-				mp_statusBarLabel->setText(msg);
-
-			QApplication::processEvents();
-		}
-
-
-	//! Update the progress feedback by message string and numerical value.
-	void
-		MainWindow::updateFeedback(QString msg, int currentValue)
-		{
-			statusBarMessage(msg);
-			statusBarProgress(currentValue);
-		}
-
-
 	//! Destroy all the plot widgets that have been created in \p originPlotWidget.
 	/*!
 
@@ -2316,6 +2529,7 @@ namespace msXpSmineXpert
 	void
 		MainWindow::seedInitialPlots(MassSpecDataSet *p_massSpecDataSet)
 		{
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter";
 
 			// Each new plot must have a different color than all the others already
 			// used, such that we can distinguish the files throughout all the
@@ -2355,111 +2569,31 @@ namespace msXpSmineXpert
 				m_colorList.takeFirst();
 			}
 
-			// Before computing the TIC and plotting it, let the window know what
-			// color we wish for the plot.
-			mp_ticChromWnd->setWishedColor(*useColor);
-
-			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			//<< "setting wished color:" << *useColor;
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "setting wished color:" << *useColor;
 
+			//qDebug() << __FILE__ << __LINE__ << "Calculating the TIC chromatogram...";
 			// Now compute the TIC and plot it. The function returns the plot widget
 			// that displays the chromatogram for this mass spec data set.
 
-			//qDebug() << __FILE__ << __LINE__ << "Calculating the TIC chromatogram...";
-			//statusBarMessage("Calculating the TIC chromatogram...");
-			//logConsoleMessage("Calculating the TIC chromatogram...\n");
+			//connect(mp_ticChromWnd,
+			//&TicChromWnd::initialTicDoneSignal,
+			//this,
+			//&MainWindow::initialTicDone);
 
-			AbstractPlotWidget *widget = mp_ticChromWnd->initialTic(p_massSpecDataSet);
+			connect(mp_colorMapWnd,
+					&ColorMapWnd::initialColorMapDoneSignal,
+					this,
+					&MainWindow::initialColorMapDone);
 
-			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			//<< "Done the initialTic computation.";
+			mp_ticChromWnd->initialTic(p_massSpecDataSet, *useColor);
 
-			if(widget == Q_NULLPTR)
-			{
-				QMessageBox msgBox;
-				msgBox.setText(
-						"The program failed to compute an initial TIC chromatogram. Please,"
-						" ensure that the file being loaded is correct.");
+			statusBarMessage("Calculating the TIC chromatogram...");
+			logConsoleMessage("Calculating the TIC chromatogram...\n");
 
-				msgBox.setStandardButtons(QMessageBox::Ok);
-				msgBox.exec();
-
-				delete p_massSpecDataSet;
-
-				return;
-			}
-
-			//qDebug() << __FILE__ << __LINE__
-			//<< "Done calculating the TIC chromatogram...";
-
-			statusBarMessage("Done calculating the TIC chromatogram...");
-			logConsoleMessage("Done calculating the TIC chromatogram...\n");
-
-			// Add a new item to the open spectrum dialog window widget list such
-			// that we'll know which files are open. Note that the function below
-			// will create a mapping between the list widget item and the tic chrom plot
-			// widget that is set to be the parent of p_massSpecDataSet.
-			QListWidgetItem *item =
-				mp_openSpectraDlg->addOpenSpectrum(p_massSpecDataSet, *useColor);
-
-			// The root relation is when the relation has no origin plot widget but
-			// has a target plot widget. This is how a relation is recognized to
-			// describe a root plot widget.
-			m_dataPlotWidgetRelationer.newRelation(
-					p_massSpecDataSet, Q_NULLPTR /*origin plot widget */,
-					widget /*target plot widget */, item);
-
-			// Now make sure that the open spectra dialog's list widget item is
-			// selected by default.
-
-			mp_openSpectraDlg->selectPlotWidget(widget);
-
-			// At this time, we now can compute the initial color map, thus generating
-			// a new plot widget that we will associate to the tic chrom plot widget.
-
-			// The color map that relates the drift time with the m/z with the
-			// intensity of the m/z as a color map.
-			// To be able to identify the colormap as related to a given tic
-			// chromatogram plot widget, we'll set its background to the same color.
-			mp_colorMapWnd->setWishedColor(*useColor);
-
-			// Right before starting the color map calculation, that can be lengthy,
-			// make sure we show it on the fore for the user to see it.
-
-			showColorMapWnd();
-
-			bool ok = false;
-
-			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			//<< "Now starting the color map initialization.";
-			AbstractPlotWidget *colorMapPlotWidget =
-				mp_colorMapWnd->initialColorMap(p_massSpecDataSet, &ok);
-			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			//<< "Finished the color map initialization.";
-
-			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
-			//<< "fileName:" << p_massSpecDataSet->fileName();
-
-			if(colorMapPlotWidget == Q_NULLPTR)
-			{
-				if(!ok)
-					qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
-
-				// The data were not from an ion mobility mass spectrometry experiment,
-				// so no problem.
-
-				//qDebug() << __FILE__ << __LINE__
-				//<< "Returned Q_NULLPTR color map widget. The data do not contain mobility data.";
-			}
-			else
-			{
-				// The colormap is considered to be a descendant from the TIC:
-
-				m_dataPlotWidgetRelationer.newRelation(
-						p_massSpecDataSet, widget /*origin plot widget */,
-						colorMapPlotWidget /*target plot widget */,
-						Q_NULLPTR /* openspectradlglistwidgetitem */);
-			}
+			// The initialTic function from TicChromWnd will emit the
+			// initialTicDoneSignal. From that signal slot function, the process of
+			// calculating the color map is started.
 		}
 
 
