@@ -80,7 +80,7 @@ namespace msXpSmineXpert
 	MassSpecPlotWidget::MassSpecPlotWidget(QWidget * parent,
 			const QString & name,
 			const QString & desc,
-			MassSpecDataSet * massSpecDataSet,
+			const MassSpecDataSet * massSpecDataSet,
 			const QString & fileName,
 			bool isMultiGraph)
 		:
@@ -139,8 +139,8 @@ namespace msXpSmineXpert
 			if(m_xDelta >= 0.9 && m_xDelta <= 1.1)
 			{
 				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-					//<< "m_xDelta:" << m_xDelta
-					//<< "trying isotope-based deconvolution.";
+				//<< "m_xDelta:" << m_xDelta
+				//<< "trying isotope-based deconvolution.";
 
 				return deconvoluteIsotopicCluster();
 			}
@@ -153,7 +153,7 @@ namespace msXpSmineXpert
 			int span = wnd->chargeSpan();
 
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "span is:" << span;
+			//<< "span is:" << span;
 
 			return deconvoluteChargedState(span);
 		}
@@ -200,7 +200,7 @@ namespace msXpSmineXpert
 			{
 				m_lastCharge = -1;
 				m_lastMz = qSNaN();
-				m_lastI = qSNaN();
+				m_lastTicIntensity = qSNaN();
 				m_lastMass = qSNaN();
 
 				return false;
@@ -256,20 +256,20 @@ namespace msXpSmineXpert
 			// envelope.
 
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
-				//<< "Charge:" << chargeIntPart
-				//<< "Charge fractional part: " << chargeFracPart;
+			//<< "Charge:" << chargeIntPart
+			//<< "Charge fractional part: " << chargeFracPart;
 
 			if(chargeFracPart >= (1 - m_chargeFracPartTolerance /* that is >= 0.01 */) &&
 					chargeFracPart <= m_chargeFracPartTolerance /* that is <= 0.99 */)
 			{
 				m_lastCharge = -1;
 				m_lastMz = qSNaN();
-				m_lastI = qSNaN();
+				m_lastTicIntensity = qSNaN();
 				m_lastMass = qSNaN();
 
 				//qDebug() << __FILE__ << __LINE__
-					//<< "Not a charge state family peak,"
-					//<< "returning from deconvoluteChargeState";
+				//<< "Not a charge state family peak,"
+				//<< "returning from deconvoluteChargeState";
 
 				return false;
 			}
@@ -309,10 +309,10 @@ namespace msXpSmineXpert
 			m_lastMass = (curMz * m_lastCharge) - (m_lastCharge * m_protonMass);
 
 			//qDebug() << __FILE__ << __LINE__
-				//<< "startMz:" << QString("%1").arg(startMz, 0, 'f', 6)
-				//<< "m_lastMz (curMz):" << QString("%1").arg(m_lastMz, 0, 'f', 6)
-				//<< "m_lastMass:" << QString("%1").arg(m_lastMass, 0, 'f', 6)
-				//<< "m_lastCharge:" << QString("%1").arg(m_lastCharge);
+			//<< "startMz:" << QString("%1").arg(startMz, 0, 'f', 6)
+			//<< "m_lastMz (curMz):" << QString("%1").arg(m_lastMz, 0, 'f', 6)
+			//<< "m_lastMass:" << QString("%1").arg(m_lastMass, 0, 'f', 6)
+			//<< "m_lastCharge:" << QString("%1").arg(m_lastCharge);
 
 			return true;
 		}
@@ -375,7 +375,7 @@ namespace msXpSmineXpert
 			{
 				m_lastCharge = -1;
 				m_lastMz = qSNaN();
-				m_lastI = qSNaN();
+				m_lastTicIntensity = qSNaN();
 				m_lastMass = qSNaN();
 				m_keyRangeStart = qSNaN();
 				m_keyRangeEnd = qSNaN();
@@ -619,7 +619,7 @@ namespace msXpSmineXpert
 					}
 					if(curChar == 'I')
 					{
-						stanza += QString("%1").arg(m_lastI, 0, 'g', 3);
+						stanza += QString("%1").arg(m_lastTicIntensity, 0, 'g', 3);
 
 						prevChar = ' ';
 						continue;
@@ -866,14 +866,14 @@ namespace msXpSmineXpert
 	 */
 
 	//! Perform a ranged [\p lower -- \p upper] data integration to a single TIC intensity value.
-	double
+	void
 		MassSpecPlotWidget::integrateToTicIntensity(double lower, double upper)
 		{
 			if(m_isMultiGraph)
 				// We cannot perform the action, because this plot widget has not mass
 				// spec data set pointer, it is a graph-only plot widget to display all
 				// the graphs overlaid.
-				return 0;
+				return;
 
 			// Get the pointer to the x-axis (key axis).
 
@@ -897,11 +897,11 @@ namespace msXpSmineXpert
 			m_keyRangeEnd = qSNaN();
 
 			// Also reset the other datum that might hold invalid values.
-			m_lastI = qSNaN();
+			m_lastTicIntensity = qSNaN();
 
 			if(rangeStart == rangeEnd)
 			{
-				return false;
+				return;
 			}
 
 			// Slot for sorting stuff.
@@ -927,47 +927,35 @@ namespace msXpSmineXpert
 			// Aggreate the new item to the local history copy we made.
 			localHistory.appendHistoryItem(histItem);
 
-			MassSpecWnd *parentWnd = static_cast<MassSpecWnd *>(mp_parentWnd);
-
-			// Capture immediately the text that is located in the status bar
-			// because if the computation is long that text will have disappeared
-			// and we won't be able to show it in the TIC int text.
-
-			QString currentMessage = parentWnd->statusBar()->currentMessage();
-
-			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
-
 			// Sanity check. It is not possible that this plot widget is not
 			// multi-graph and that at the same time, the mass spec data set pointer
 			// is nullptr.
-
 			if(!m_isMultiGraph && mp_massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d -- %s(). "
 						"Programming error."
 						"Program aborted.",
 						__FILE__, __LINE__, __FUNCTION__);
 
-			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
+			// Capture immediately the text that is located in the status bar
+			// because if the computation is long that text will have disappeared
+			// and we won't be able to show it in the TIC int text.
 
-			integrator.integrateToTicIntensity();
-
-			m_lastI = integrator.ticIntensity();
-
-			QApplication::restoreOverrideCursor();
+			QMainWindow *parentWnd = static_cast<QMainWindow *>(mp_parentWnd);
+			QString currentMessage = parentWnd->statusBar()->currentMessage();
 
 			if(currentMessage.isEmpty())
-				parentWnd->statusBar()->showMessage(QString("range [%1-%2]: TIC I = %3")
-						.arg(m_keyRangeStart, 0, 'f', 3)
-						.arg(m_keyRangeEnd, 0, 'f', 3)
-						.arg(m_lastI, 0, 'g', 3));
+				currentMessage = QString("range [%1-%2]")
+					.arg(m_keyRangeStart, 0, 'f', 3)
+					.arg(m_keyRangeEnd, 0, 'f', 3);
 			else
-				parentWnd->statusBar()->showMessage(currentMessage +
-						QString(" ; range [%1-%2]: TIC I = %3")
-						.arg(m_keyRangeStart, 0, 'f', 3)
-						.arg(m_keyRangeEnd, 0, 'f', 3)
-						.arg(m_lastI, 0, 'g', 3));
+				currentMessage += QString(" ; range [%1-%2]")
+					.arg(m_keyRangeStart, 0, 'f', 3)
+					.arg(m_keyRangeEnd, 0, 'f', 3);
 
-			return m_lastI;
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "Emitting ticIntensitySignal";
+
+			emit ticIntensitySignal(mp_massSpecDataSet, currentMessage, localHistory);
 		}
 
 
