@@ -200,8 +200,8 @@ namespace msXpSmineXpert
 				ScriptEntityType::FunctionEntity,
 				&result);
 
-		qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			"Now making available all the scriptable classes to the scripting environment";
+		//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//"Now making available all the scriptable classes to the scripting environment";
 
 		// Make sure we make the DataPoint class available to the script environment.
 		msXpSlibmass::DataPointJs *dataPointJs = new msXpSlibmass::DataPointJs(&m_scriptEngine);
