@@ -321,9 +321,6 @@ namespace msXpSmineXpert
 
 			m_ui.formatStringLineEdit->setText(
 					"%f-export-slice-%n-of-%c-range_%s-%e.db");
-
-			// Finally set the fileName to the sqlHandler
-			m_sqlHandler.setFileName(fileName);
 		}
 
 
@@ -792,8 +789,6 @@ namespace msXpSmineXpert
 
 			// When the sql data handler will perform the export, it will emit
 			// progression signals. Make the connecions.
-			connect(&sqlHandler, &MassSpecSqlite3Handler::setupFeedbackSignal,
-					this, &SqlMassDataSlicerWnd::setupFeedback);
 			connect(&sqlHandler, &MassSpecSqlite3Handler::updateFeedbackSignal,
 					this, &SqlMassDataSlicerWnd::updateFeedback);
 
@@ -873,31 +868,20 @@ namespace msXpSmineXpert
 		}
 
 
-	//! Setup the feedback system to inform the user of the progress of the operation.
-	void
-		SqlMassDataSlicerWnd::setupFeedback(QString msg, int startValue,
-				int endValue, int currentValue)
-		{
-			m_ui.feedbackProgressBar->setMinimum(startValue);
-			m_ui.feedbackProgressBar->setMaximum(endValue);
-
-			if(currentValue != -1)
-				m_ui.feedbackProgressBar->setValue(currentValue);
-
-			if(!msg.isEmpty())
-				m_ui.feedbackLineEdit->setText(msg);
-
-			QApplication::processEvents();
-		}
-
-
 	//! Update the feedback to the user.
-	void
-		SqlMassDataSlicerWnd::updateFeedback(QString msg, int currentValue)
+			void
+				SqlMassDataSlicerWnd::updateFeedback(QString msg, int currentValue,
+					bool setVisible, int startValue, int endValue)
 		{
 			m_ui.feedbackLineEdit->setText(msg);
 			m_ui.feedbackProgressBar->setValue(currentValue);
 
+			if(startValue != -1)
+			m_ui.feedbackProgressBar->setMinimum(startValue);
+
+			if(endValue != -1)
+			m_ui.feedbackProgressBar->setMaximum(endValue);
+
 			// Process the app events, to refresh the GUI.
 			QApplication::processEvents();
 		}
