@@ -82,7 +82,7 @@ namespace msXpSmineXpert
 */
 	TicChromPlotWidget::TicChromPlotWidget(QWidget *parent,
 			const QString &name, const QString &desc,
-			MassSpecDataSet *massSpecDataSet, const QString &fileName,
+			const MassSpecDataSet *massSpecDataSet, const QString &fileName,
 			bool isMultiGraph)
 		: AbstractPlotWidget{parent,
 			name, desc,
@@ -321,7 +321,7 @@ namespace msXpSmineXpert
 					}
 					if(curChar == 'I')
 					{
-						stanza += QString("%1").arg(m_lastI, 0, 'g', 3);
+						stanza += QString("%1").arg(m_lastTicIntensity, 0, 'g', 3);
 
 						prevChar = ' ';
 						continue;
@@ -537,14 +537,14 @@ namespace msXpSmineXpert
 	 */
 
 	//! Perform a ranged [\p lower -- \p upper] data integration to a single TIC intensity value.
-	double
+	void
 		TicChromPlotWidget::integrateToTicIntensity(double lower, double upper)
 		{
 			if(m_isMultiGraph)
 				// We cannot perform the action, because this plot widget has not mass
 				// spec data set pointer, it is a graph-only plot widget to display all
 				// the graphs overlaid.
-				return 0;
+				return ;
 
 			// Get the pointer to the x-axis (key axis).
 
@@ -568,11 +568,11 @@ namespace msXpSmineXpert
 			m_keyRangeEnd = qSNaN();
 
 			// Also reset the other datum that might hold invalid values.
-			m_lastI = qSNaN();
+			m_lastTicIntensity = qSNaN();
 
 			if(rangeStart == rangeEnd)
 			{
-				return false;
+				return;
 			}
 
 			// Slot for sorting stuff.
@@ -598,47 +598,35 @@ namespace msXpSmineXpert
 			// Aggreate the new item to the history.
 			localHistory.appendHistoryItem(histItem);
 
-			TicChromWnd *parentWnd = static_cast<TicChromWnd *>(mp_parentWnd);
-
-			// Capture immediately the text that is located in the status bar
-			// because if the computation is long that text will have disappeared
-			// and we won't be able to show it in the TIC int text.
-
-			QString currentMessage = parentWnd->statusBar()->currentMessage();
-
-			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
-
 			// Sanity check. It is not possible that this plot widget is not
 			// multi-graph and that at the same time, the mass spec data set pointer
 			// is nullptr.
-
 			if(!m_isMultiGraph && mp_massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d -- %s(). "
 						"Programming error."
 						"Program aborted.",
 						__FILE__, __LINE__, __FUNCTION__);
 
-			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
+			// Capture immediately the text that is located in the status bar
+			// because if the computation is long that text will have disappeared
+			// and we won't be able to show it in the TIC int text.
 
-			integrator.integrateToTicIntensity();
-
-			m_lastI = integrator.ticIntensity();
-
-			QApplication::restoreOverrideCursor();
+			QMainWindow *parentWnd = static_cast<QMainWindow *>(mp_parentWnd);
+			QString currentMessage = parentWnd->statusBar()->currentMessage();
 
 			if(currentMessage.isEmpty())
-				parentWnd->statusBar()->showMessage(QString("range [%1-%2]: TIC I = %3")
-						.arg(m_keyRangeStart, 0, 'f', 3)
-						.arg(m_keyRangeEnd, 0, 'f', 3)
-						.arg(m_lastI, 0, 'g', 3));
+				currentMessage = QString("range [%1-%2]")
+					.arg(m_keyRangeStart, 0, 'f', 3)
+					.arg(m_keyRangeEnd, 0, 'f', 3);
 			else
-				parentWnd->statusBar()->showMessage(currentMessage +
-						QString(" ; range [%1-%2]: TIC I = %3")
-						.arg(m_keyRangeStart, 0, 'f', 3)
-						.arg(m_keyRangeEnd, 0, 'f', 3)
-						.arg(m_lastI, 0, 'g', 3));
+				currentMessage += QString(" ; range [%1-%2]")
+					.arg(m_keyRangeStart, 0, 'f', 3)
+					.arg(m_keyRangeEnd, 0, 'f', 3);
 
-			return m_lastI;
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "Emitting ticIntensitySignal";
+
+			emit ticIntensitySignal(mp_massSpecDataSet, currentMessage, localHistory);
 		}
 
 
@@ -874,8 +862,7 @@ namespace msXpSmineXpert
 							// tic
 							// chrom plot widget's mass spec data set:
 							QString fileName =
-								static_cast<TicChromPlotWidget *>(ticChromPlotWidget)
-								->mp_massSpecDataSet->fileName();
+								static_cast<TicChromPlotWidget *>(ticChromPlotWidget)->mp_massSpecDataSet->fileName();
 
 							stanza = craftAnalysisStanza(iterGraph, fileName);
 
