@@ -114,9 +114,9 @@ namespace msXpSmineXpert
 			mp_multiGraphPlotWidget->setObjectName("multiGraphPlot");
 
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				<< "Created new multigraph TIC plot widget:"
-				<< mp_multiGraphPlotWidget << "window:" << this;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< "Created new multigraph TIC plot widget:"
+			//<< mp_multiGraphPlotWidget << "window:" << this;
 
 			// We need to remove the single graph that was created upon creation of
 			// the QCustomPlot widget because we'll later add graphs, and we want to
@@ -182,8 +182,8 @@ namespace msXpSmineXpert
 	TicChromPlotWidget *
 		TicChromWnd::addPlotWidget(const QVector<double> &keyVector,
 				const QVector<double> &valVector,
-				const QString &desc,
-				MassSpecDataSet *massSpecDataSet,
+				const QString &desc, const QColor & color,
+				const MassSpecDataSet *massSpecDataSet,
 				bool isMultiGraph)
 		{
 			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
@@ -237,15 +237,7 @@ namespace msXpSmineXpert
 
 			widget->graph()->setData(keyVector, valVector);
 
-			// Let's see if one color was set as the desired color, otherwise use
-			// black.
-
-			QColor localColor = Qt::black;
-
-			if(m_wishedColor.isValid())
-				localColor = m_wishedColor;
-
-			widget->setPlottingColor(localColor);
+			widget->setPlottingColor(color);
 
 			widget->rescaleAxes(true /*only enlarge*/);
 			widget->replot();
@@ -288,9 +280,12 @@ namespace msXpSmineXpert
 		}
 
 
-	AbstractPlotWidget *
-		TicChromWnd::initialTic(MassSpecDataSet *p_massSpecDataSet)
+	void
+		TicChromWnd::initialTic(const MassSpecDataSet *p_massSpecDataSet, QColor color)
 		{
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
+				<< " - current thread id:" << QThread::currentThreadId()
+				<< "with color:" << color;
 
 			if(p_massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d -- %s(). "
@@ -298,14 +293,81 @@ namespace msXpSmineXpert
 						"Program aborted.",
 						__FILE__, __LINE__, __FUNCTION__);
 
-			// The mass data integration processes are handled by the
-			// MassDataIntegrator object.
+			mp_statusBarCancelPushButton->setVisible(true);
 
-			MassDataIntegrator integrator(p_massSpecDataSet);
+			// QThread will start the thread in which the integrator will work.
+			QThread* thread = new QThread;
 
-			integrator.initialTic();
+			// The integrator will perform the integration itself.
+			MassDataIntegrator *integrator = new MassDataIntegrator(p_massSpecDataSet);
 
-			History localHistory = integrator.history();
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "Allocated new integrator:" << integrator;
+
+			integrator->moveToThread(thread);
+
+			// Calling thread->start (QThread::start()) will automatically call the
+			// integrateToMz() function of the integrator.
+			connect(thread, SIGNAL(started()), integrator, SLOT(initialTic()));
+
+			// When the integration is finished it emits resultsReadySignal and thus
+			// we can stop the *real* thread in the QThread thread instance, using the
+			// signal/slot mechanism. That is not like calling QThead::quit() !!!
+			connect(integrator, SIGNAL(resultsReadySignal()), thread, SLOT(quit()));
+
+			// This will be needed later.
+			connect(integrator,
+					&MassDataIntegrator::resultsReadySignal,
+					this,
+					[integrator, color, this] ()
+					{
+					initialTicDone(integrator, color);
+					}
+					);
+
+			connect(thread, SIGNAL(finished()), thread, SLOT(deleteLater()));
+
+			connect(integrator,
+					&MassDataIntegrator::updateFeedbackSignal,
+					this,
+					&AbstractMultiPlotWnd::updateFeedback);
+
+			connect(this,
+					&AbstractMultiPlotWnd::cancelOperationSignal,
+					integrator,
+					&MassDataIntegrator::cancelOperation);
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< " - current thread id:" << QThread::currentThreadId()
+			//<< "going to thread->start()";
+
+			thread->start();
+		}
+
+
+	void
+		TicChromWnd::initialTicDone(MassDataIntegrator *integrator, QColor color)
+		{
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "() - enter"
+			//<< " - current thread id:" << QThread::currentThreadId()
+			//<< "with color:" << color
+			//<< "with integrator:" << integrator
+			//<< "and this:" << this;
+
+			// Immediately get pointers and objects out of integrator that we'll
+			// delete soon.
+			const MassSpecDataSet *massSpecDataSet = integrator->massSpecDataSet();
+			History localHistory = integrator->history();
+
+			//De-setup the feedback.
+			QTimer::singleShot(2000, this, [=]()
+					{
+					updateFeedback("", -1, false /* setVisible */, LogType::LOG_TO_STATUS_BAR);
+					}
+					);
+
+			// Make sure the cancel button is hidden.
+			mp_statusBarCancelPushButton->setVisible(false);
 
 			// At this point what we should do is transfer the data to the plotting
 			// widget creation routine. Note that we are creating the very first plot
@@ -315,43 +377,83 @@ namespace msXpSmineXpert
 			// call below).
 
 			AbstractPlotWidget *widget = addPlotWidget(
-					integrator.keyVector(), integrator.valVector(),
-					p_massSpecDataSet->fileName(), p_massSpecDataSet);
+					integrator->keyVector(), integrator->valVector(),
+					massSpecDataSet->fileName(),
+					color, massSpecDataSet);
+
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "created a new widget for the tic chromatogram:" << widget
+				<< "with massSpecDataSet:" << massSpecDataSet;
+
+			// Finally we can delete the integrator
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "Finally deleting the integrator object:" << integrator;
+			delete integrator;
+			integrator = Q_NULLPTR;
 
 			// For this specific TIC chrom widget, that is created for storing the
 			// initial mass spec data set as read from file, we set it as parent of
 			// the mass spec data set, so that when the widget is destroyed, the mass
-			// spec data set also.
-			p_massSpecDataSet->setParent(widget);
+			// spec data set also. Ugly, but we need to cast to non-const.
+			const_cast<MassSpecDataSet *>(massSpecDataSet)->setParent(widget);
 
 			// Before updating the history of the widget, update the history with the
 			// two critical data bits that will be conditioning the way future
 			// integrations are performed: the smallestStep value that goes along the
 			// msXpS::MassToleranceType::MASS_TOLERANCE_MZ.
 
-			MassSpecDataStats stats = p_massSpecDataSet->statistics();
+			MassSpecDataStats stats = massSpecDataSet->statistics();
 
-			// Use the statistics to setup the initial mz integration params to the
-			// history of the plot widget. Note that we set the binning type to
-			// arbitrary with the bin size set to twice the smallest m/z step observed
-			// throughout all the data points of all the spectra of the file.
-			MzIntegrationParams params(BinningType::BINNING_TYPE_ARBITRARY,
+			MzIntegrationParams paramsToApply;
 
-					// this was the first version, but that value is not robuts: many
-					// times it happens to be 0, so the 0.001 default value would be set.
-					// That m_smallestStep value is too low for most occasions.
-					// m_smallestStep,
+			if(stats.m_spectrumCount <= 1)
+			{
+				// There is no interest to perform any binning when there is at most one
+				// spectrum.
 
-					// The m_smallestStepAvg is the most robust.
-					stats.m_smallestStepAvg,
-					msXpS::MassToleranceType::MASS_TOLERANCE_MZ,
-					false /* apply mz shift */,
-					false /* remove 0-val data points */);
+				MzIntegrationParams params(BinningType::BINNING_TYPE_NONE,
+						0.005,
+						msXpS::MassToleranceType::MASS_TOLERANCE_MZ,
+						false /* apply mz shift */,
+						false /* remove 0-val data points */);
+
+				paramsToApply = params;
+			}
+			else
+			{
+				// Use the statistics to setup the initial mz integration params to the
+				// history of the plot widget. Note that we set the binning type to
+				// arbitrary with the bin size set to twice the smallest m/z step observed
+				// throughout all the data points of all the spectra of the file.
+
+				MzIntegrationParams params(BinningType::BINNING_TYPE_ARBITRARY,
+
+						// This was the first version, but that value is not robuts: many
+						// times it happens to be 0, so the 0.001 default value would be set.
+						// That m_smallestStep value is too low for most occasions.
+						// m_smallestStep,
+
+						// This was the second version:
+						// The m_smallestStepAvg is the most robust.
+						// stats.m_smallestStepAvg,
+
+						// This is currently the last version
+						// The m_smallestMedian is the most robust.
+						stats.m_smallestStepMedian,
+						msXpS::MassToleranceType::MASS_TOLERANCE_MZ,
+						false /* apply mz shift */,
+
+						// Note that when binning is set, then removing the 0-val data points
+						// is recommended.
+						true /* remove 0-val data points */);
+
+				paramsToApply = params;
+			}
 
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "stats.m_smallestStepAvg =" << stats.m_smallestStepAvg;
+			//<< "stats.m_smallestStepAvg =" << stats.m_smallestStepAvg;
 
-			localHistory.setMzIntegrationParams(params);
+			localHistory.setMzIntegrationParams(paramsToApply);
 
 			// At this point, make sure that the widget has the new version of the
 			// history.
@@ -366,10 +468,10 @@ namespace msXpSmineXpert
 			//<< "After initialTic was computed, history:"
 			//<< widget->history().asText();
 
-			mainWindow->logConsoleMessage(stats.asText(), m_wishedColor);
+			mainWindow->logConsoleMessage(stats.asText(), color);
 
-			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			//<< "Statistics: " << p_massSpecDataSet->statisticsAsText();
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				<< "Statistics: " << massSpecDataSet->statisticsAsText();
 
 			// The plot widget reacts to the Qt::Key_Delete key by calling a function
 			// that emits a set of signals, of which the destroyPlotWidget signal
@@ -399,9 +501,15 @@ namespace msXpSmineXpert
 					&DriftSpecWnd::newDriftSpectrum);
 
 			connect(static_cast<TicChromPlotWidget *>(widget),
-					&TicChromPlotWidget::newTicChromatogram, this,
+					&TicChromPlotWidget::newTicChromatogram,
+					this,
 					&TicChromWnd::newTicChromatogram);
 
+			connect(static_cast<TicChromPlotWidget *>(widget),
+					&TicChromPlotWidget::ticIntensitySignal,
+					this,
+					&TicChromWnd::ticIntensity);
+
 			// Ensure that there is a connection between this plot widget and this
 			// containing window, such that if there is a requirement to replot, the
 			// widget gets the signal.
@@ -418,7 +526,10 @@ namespace msXpSmineXpert
 			mp_lastFocusedPlotWidget = widget;
 			updateMzIntegrationParams(widget->history().mzIntegrationParams());
 
-			return widget;
+			// Now call the main window of the program to finalize the widget
+			// establishment.
+
+			mainWindow->initialTicDone(widget, massSpecDataSet, color);
 		}
 
 
@@ -436,45 +547,81 @@ namespace msXpSmineXpert
 
 */
 	void
-		TicChromWnd::newTicChromatogram(MassSpecDataSet *massSpecDataSet,
+		TicChromWnd::newTicChromatogram(const MassSpecDataSet *massSpecDataSet,
 				const QString &msg, History history, QColor color)
 		{
-			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			//<< "Entering";
 
 			if(massSpecDataSet == Q_NULLPTR)
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Pointer cannot be nullptr."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
 
-			m_wishedColor = color;
 
-			// Make sure the cancel button is visible.
+			// Plot widget relation between the caller widget and the newly created
+			// widget later on.
+			AbstractPlotWidget *senderPlotWidget = static_cast<AbstractPlotWidget *>(QObject::sender());
+
 			mp_statusBarCancelPushButton->setVisible(true);
 
-			MassDataIntegrator integrator(massSpecDataSet, history);
+			// QThread will start the thread in which the integrator will work.
+			QThread* thread = new QThread;
 
-			connect(&integrator,
-					&MassDataIntegrator::setupFeedbackSignal,
+			// The integrator will perform the integration itself.
+			MassDataIntegrator *integrator = new MassDataIntegrator(massSpecDataSet, history);
+
+			integrator->moveToThread(thread);
+
+			// Calling thread->start (QThread::start()) will automatically call the
+			// integrateToMz() function of the integrator.
+			connect(thread, SIGNAL(started()), integrator, SLOT(integrateToRt()));
+
+			// When the integration is finished it emits resultsReadySignal and thus
+			// we can stop the *real* thread in the QThread thread instance, using the
+			// signal/slot mechanism. That is not like calling QThead::quit() !!!
+			connect(integrator, SIGNAL(resultsReadySignal()), thread, SLOT(quit()));
+
+			// This will be needed later, when we'll create a data plot relation
+			// object relating the sender plot widget with the newly created one (in
+			// newTicChromatogramDone).
+			connect(integrator,
+					&MassDataIntegrator::resultsReadySignal,
 					this,
-					&AbstractMultiPlotWnd::setupFeedback);
+					[integrator, senderPlotWidget, color, this] ()
+					{
+					newTicChromatogramDone(integrator,
+							senderPlotWidget, color);
+					}
+					);
 
-			connect(&integrator,
+			connect(thread, SIGNAL(finished()), thread, SLOT(deleteLater()));
+
+			connect(integrator,
 					&MassDataIntegrator::updateFeedbackSignal,
 					this,
 					&AbstractMultiPlotWnd::updateFeedback);
 
 			connect(this,
 					&AbstractMultiPlotWnd::cancelOperationSignal,
-					&integrator,
+					integrator,
 					&MassDataIntegrator::cancelOperation);
 
-			integrator.integrate();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< " - current thread id:" << QThread::currentThreadId();
 
-			//qDebug() << "At this point the integration is finished. Desetup the feedback.";
+			thread->start();
+		}
+
+	void
+		TicChromWnd::newTicChromatogramDone(msXpSmineXpert::MassDataIntegrator *integrator,
+				msXpSmineXpert::AbstractPlotWidget *senderPlotWidget, QColor color)
+		{
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
 			//De-setup the feedback.
 			QTimer::singleShot(2000, this, [=]()
 					{
-					setupFeedback("", -1, -1, -1, LogType::LOG_TO_STATUS_BAR);
+					updateFeedback("", -1, false /* setVisible */, LogType::LOG_TO_STATUS_BAR);
 					}
 					);
 
@@ -483,23 +630,23 @@ namespace msXpSmineXpert
 
 			// Create a text item to indicate the last history item.
 
-			QString historyItemText = history.newestHistoryItem()->asText(true /* brief */);
+			QString historyItemText = integrator->history().newestHistoryItem()->asText(true /* brief */);
 
 			QString plotText = QString("%1\n%2 - %3 ")
-				.arg(massSpecDataSet->fileName())
+				.arg(integrator->massSpecDataSet()->fileName())
 				.arg(m_desc)
 				.arg(historyItemText);
 
 			// Allocate the new plot widget in which the data are to be plot.
 
 			TicChromPlotWidget *widget = static_cast<TicChromPlotWidget *>(
-					addPlotWidget(integrator.keyVector(), integrator.valVector(),
-						plotText, massSpecDataSet));
+					addPlotWidget(integrator->keyVector(), integrator->valVector(),
+						plotText, color, integrator->massSpecDataSet()));
 
 			// The history that we get as a parameter needs to be appended to the new
 			// widget's history so that we have a full account of the history.
 
-			widget->rhistory().copyHistory(history, true /*remove duplicates*/);
+			widget->rhistory().copyHistory(integrator->history(), true /*remove duplicates*/);
 
 			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
 			mainWindow->logConsoleMessage(widget->history().asText(
@@ -540,27 +687,115 @@ namespace msXpSmineXpert
 			connect(widget, &TicChromPlotWidget::newDriftSpectrum,
 					mainWindow->mp_driftSpecWnd, &DriftSpecWnd::newDriftSpectrum);
 
+			// FIXME For the XIC extraction ?
 			connect(widget, &TicChromPlotWidget::newTicChromatogram,
 					this, &TicChromWnd::newTicChromatogram);
 
-			AbstractPlotWidget *senderPlotWidget =
-				dynamic_cast<AbstractPlotWidget *>(QObject::sender());
-
-			if(senderPlotWidget == Q_NULLPTR)
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+			connect(widget, &TicChromPlotWidget::ticIntensitySignal,
+					mainWindow->mp_ticChromWnd, &TicChromWnd::ticIntensity);
 
 			mainWindow->m_dataPlotWidgetRelationer.newRelation(
-					massSpecDataSet, senderPlotWidget, widget,
+					integrator->massSpecDataSet(), senderPlotWidget, widget,
 					Q_NULLPTR /* open spectra dialog list widget item */);
 
-			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-			//<< "Exiting";
+			// Finally we can destroy the integrator.
+			delete integrator;
 		}
 
 
+	void
+		TicChromWnd::ticIntensity(const MassSpecDataSet *massSpecDataSet,
+				const QString &msg, History history)
+		{
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+
+			if(massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			mp_statusBarCancelPushButton->setVisible(true);
+
+			AbstractPlotWidget *senderPlotWidget = static_cast<AbstractPlotWidget *>(QObject::sender());
+
+			// QThread will start the thread in which the integrator will work.
+			QThread* thread = new QThread;
+
+			// The integrator will perform the integration itself.
+			MassDataIntegrator *integrator = new MassDataIntegrator(massSpecDataSet, history);
+
+			integrator->moveToThread(thread);
+
+			// Calling thread->start (QThread::start()) will automatically call the
+			// integrateToTicIntensity() function of the integrator.
+			connect(thread, SIGNAL(started()), integrator, SLOT(integrateToTicIntensity()));
+
+			// When the integration is finished it emits resultsReadySignal and thus
+			// we can stop the *real* thread in the QThread thread instance, using the
+			// signal/slot mechanism. That is not like calling QThead::quit() !!!
+			connect(integrator, SIGNAL(resultsReadySignal()), thread, SLOT(quit()));
+
+			// This will be needed later, when we'll create a data plot relation
+			// object relating the sender plot widget with the newly created one (in
+			// ticIntensityDone).
+			connect(integrator,
+					&MassDataIntegrator::resultsReadySignal,
+					this,
+					[integrator, msg, senderPlotWidget, this] ()
+					{
+					ticIntensityDone(integrator, msg, senderPlotWidget);
+					}
+					);
+
+			connect(thread, SIGNAL(finished()), thread, SLOT(deleteLater()));
+
+			connect(integrator,
+					&MassDataIntegrator::updateFeedbackSignal,
+					this,
+					&AbstractMultiPlotWnd::updateFeedback);
+
+			connect(this,
+					&AbstractMultiPlotWnd::cancelOperationSignal,
+					integrator,
+					&MassDataIntegrator::cancelOperation);
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+			//<< " - current thread id:" << QThread::currentThreadId();
+
+			thread->start();
+		}
+
+
+	void
+		TicChromWnd::ticIntensityDone(MassDataIntegrator *integrator, QString msg,
+				AbstractPlotWidget *senderPlotWidget)
+		{
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+
+			//De-setup the feedback.
+			QTimer::singleShot(2000, this, [=]()
+					{
+					updateFeedback("", -1, false /* isVisible */, LogType::LOG_TO_STATUS_BAR);
+					}
+					);
+
+			// Make sure the cancel button is hidden.
+			mp_statusBarCancelPushButton->setVisible(false);
+
+			// Set the proper value in the plot widget right away so that it can be
+			// queried in another context.
+			senderPlotWidget->setLastTicIntensity(integrator->ticIntensity());
+
+			// Now we can dipslay the results in the status bar:
+			statusBar()->showMessage(msg + QString(": TIC int.: %1").arg(integrator->ticIntensity()));
+
+			// Finally we can destroy the integrator.
+			delete integrator;
+		}
+
+
+
 	void
 		TicChromWnd::newPlot(AbstractPlotWidget *senderPlotWidget,
-				MassSpecDataSet *massSpecDataSet,
+				const MassSpecDataSet *massSpecDataSet,
 				QVector<double> keys, QVector<double> values,
 				const QString &msg, History history, QColor color)
 		{
@@ -570,8 +805,6 @@ namespace msXpSmineXpert
 			if(massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			m_wishedColor = color;
-
 			// Create a text item to indicate the last history item.
 
 			QString historyItemText = history.newestHistoryItem()->asText(true /* brief */);
@@ -585,7 +818,7 @@ namespace msXpSmineXpert
 			// Allocate the new plot widget in which the data are to be plot.
 
 			TicChromPlotWidget *widget = static_cast<TicChromPlotWidget *>(
-					addPlotWidget(keys, values, plotText, massSpecDataSet));
+					addPlotWidget(keys, values, plotText, color, massSpecDataSet));
 
 			// The history that we get as a parameter needs to be appended to the new
 			// widget's history so that we have a full account of the history.
