@@ -91,47 +91,15 @@ namespace msXpSmineXpert
 		otherwise.
 
 */
-	bool MassSpecDataFileLoaderSqlite3::isDriftExperiment()
+	bool MassSpecDataFileLoaderSqlite3::isDriftExperiment(MassSpecSqlite3Handler &handler,
+			QSqlDatabase &database)
 	{
 
 		// By asking the database to tell us if it has a value for driftBinCount
 		// in the metaData table we'll know if this database is for a mobility
 		// drift time experiment.
 
-		if(!m_sqlite3Handler.initializeDbForRead())
-			return -1;
-
-		QSqlQuery sqlQuery(m_sqlite3Handler.m_db);
-		bool ok = false;
-
-		QString queryString("SELECT driftBinCount from metaData");
-
-		ok = sqlQuery.exec(queryString);
-
-		if(!ok)
-		{
-			qDebug() << __FILE__ << __LINE__
-				<< "Failed to get proper data from the database.\n"
-				<< sqlQuery.lastError() << "Exiting.\n";
-
-			exit(1);
-		}
-
-		if(!sqlQuery.first())
-		{
-			qDebug() << __FILE__ << __LINE__
-				<< "Failed to get proper data from the database.\n"
-				<< sqlQuery.lastError() << "Exiting.\n";
-
-			exit(1);
-		}
-
-		int count = sqlQuery.value(0).toInt(&ok);
-
-		if(!count)
-			return false;
-
-		return true;
+		return handler.isDriftExperiment(database);
 	}
 
 
@@ -206,9 +174,9 @@ namespace msXpSmineXpert
 			double dtEnd = -1;
 			dtIntegration = history.innermostDtRange(&dtStart, &dtEnd);
 
-			qDebug() << __FILE__ << __LINE__
-				<< "dtIntegration:" << dtIntegration
-				<< "dtStart:" << dtStart << "dtEnd:" << dtEnd;
+			//qDebug() << __FILE__ << __LINE__
+			//<< "dtIntegration:" << dtIntegration
+			//<< "dtStart:" << dtStart << "dtEnd:" << dtEnd;
 
 			QString srcDbQueryString;
 
@@ -364,7 +332,8 @@ namespace msXpSmineXpert
 
 */
 	int
-		MassSpecDataFileLoaderSqlite3::loadSpectra(int firstId,
+		MassSpecDataFileLoaderSqlite3::loadSpectra(QSqlDatabase &database,
+				MassSpecSqlite3Handler &handler,	int firstId,
 				int lastId, MassSpecDataSet *massSpecDataSet, int &dataKind)
 		{
 			// We do not want to continue doing that work if the user cancelled the
@@ -372,7 +341,7 @@ namespace msXpSmineXpert
 			if(m_isOperationCancelled)
 				return 0;
 
-			if(massSpecDataSet == nullptr)
+			if(massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			// In this function we craft the proper SQL query SELECT string and
@@ -398,7 +367,7 @@ namespace msXpSmineXpert
 			else
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			return loadSpectra(sqlQueryString, massSpecDataSet, dataKind);
+			return loadSpectra(database, handler, sqlQueryString, massSpecDataSet, dataKind);
 		}
 
 
@@ -427,18 +396,15 @@ namespace msXpSmineXpert
 
 */
 	int
-		MassSpecDataFileLoaderSqlite3::loadSpectra(const QString &sqlQueryString,
-				MassSpecDataSet *p_massSpecDataSet, int &dataKind)
+		MassSpecDataFileLoaderSqlite3::loadSpectra(QSqlDatabase &database, MassSpecSqlite3Handler &handler,
+				const QString &sqlQueryString, MassSpecDataSet *p_massSpecDataSet, int &dataKind)
 		{
-			if(p_massSpecDataSet == nullptr)
+			if(p_massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			if(!m_sqlite3Handler.initializeDbForRead())
-				return -1;
+			QSqlQuery *sqlQuery = new QSqlQuery(database);
 
-			QSqlQuery *sqlQuery = new QSqlQuery(m_sqlite3Handler.m_db);
-
-			if(sqlQuery == nullptr)
+			if(sqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			bool ok = false;
@@ -530,7 +496,7 @@ namespace msXpSmineXpert
 
 				int newDataKind = MassDataKind::MASS_SPECTRA;
 				newSpectraAllocated =
-					loadSpectra(sqlQueryString, p_massSpecDataSet, newDataKind);
+					loadSpectra(database, handler, sqlQueryString, p_massSpecDataSet, newDataKind);
 
 				if(newSpectraAllocated != -1)
 				{
@@ -562,7 +528,7 @@ namespace msXpSmineXpert
 			// At this point we have to check if the data were compressed or not.
 			ok = false;
 			int compressionType;
-			ok = m_sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
+			ok = handler.m_msFileMetaData.intItem("compressionType", compressionType);
 
 			if(!ok)
 				compressionType = msXpS::DataCompression::DATA_COMPRESSION_NONE;
@@ -646,6 +612,7 @@ namespace msXpSmineXpert
 
 					if(p_massSpecDataSet->isStreamed())
 					{
+
 						// This is the chance we have to calculate the TIC for the
 						// spectrum:
 
@@ -689,7 +656,7 @@ namespace msXpSmineXpert
 							// encountered (and possibly undergoing combinations).
 
 							msXpSlibmass::Trace *p_trace =
-								p_massSpecDataSet->m_dtHash.value(dtList.at(iter), nullptr);
+								p_massSpecDataSet->m_dtHash.value(dtList.at(iter), Q_NULLPTR);
 
 							if(p_trace == Q_NULLPTR)
 							{
@@ -821,6 +788,10 @@ namespace msXpSmineXpert
 			// qDebug() << __FILE__ << __LINE__
 			// << newSpectraAllocated << "were allocated";
 
+			// We do not close the database, we do now own it, and we can recursively
+			// be accessing it by the caller!
+			// database.close();
+
 			return newSpectraAllocated;
 		}
 
@@ -841,10 +812,29 @@ namespace msXpSmineXpert
 		MassSpecDataFileLoaderSqlite3::loadSpectraByRt(
 				double retentionTime /*scanStartTime */, QList<msXpSlibmass::MassSpectrum *> *massSpectra)
 		{
-			if(massSpectra == nullptr)
+			if(massSpectra == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			if(!m_sqlite3Handler.initializeDbForRead())
+			//! Handler of SQLite3-based mass data.
+			//This loader loads data from a SQLite3-based mass spectrometry format and
+			//uses the features of the MassSpecSqlite3Handler class that is required
+			//to craft SQL-based statements to extract data from the database file.
+
+			MassSpecSqlite3Handler sqlite3Handler;
+
+			// And now, make sure the member database, the source database is fine.
+
+			QString connectionName = QString("%1/%2").arg(m_fileName).arg(msXpS::pointerAsString(this));
+
+			QSqlDatabase database = QSqlDatabase::addDatabase("QSQLITE", connectionName);
+			database.setDatabaseName(m_fileName);
+			database.open();
+
+			// Now that we have the database ready initialize the metadata for it.
+			// The initializeDbForRead ensures that m_specMetaData be filled from the
+			// database, so we can check if the data were compressed or not.
+
+			if(!sqlite3Handler.initializeDbForRead(database, true /* readMetaData */))
 			{
 				qDebug() << __FILE__ << __LINE__
 					<< "Failed to initialize the database for read.";
@@ -857,9 +847,9 @@ namespace msXpSmineXpert
 						"FROM spectralData WHERE (scanStartTime = %1)")
 				.arg(retentionTime, 0, 'f', 12);
 
-			QSqlQuery *sqlQuery = new QSqlQuery(m_sqlite3Handler.m_db);
+			QSqlQuery *sqlQuery = new QSqlQuery(database);
 
-			if(sqlQuery == nullptr)
+			if(sqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			bool ok = false;
@@ -916,7 +906,7 @@ namespace msXpSmineXpert
 			// At this point we have to check if the data were compressed or not.
 			ok = false;
 			int compressionType;
-			ok = m_sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
+			ok = sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
 
 			if(!ok)
 				compressionType = msXpS::DataCompression::DATA_COMPRESSION_NONE;
@@ -939,10 +929,6 @@ namespace msXpSmineXpert
 				msXpSlibmass::MassSpectrum *newSpectrum = new msXpSlibmass::MassSpectrum;
 				newSpectrum->initialize(p_enc64MzByteArray, p_enc64IByteArray, compressionType);
 
-				// FIXME try removing the O-m_val data points to help with Thermo
-				// Orbitrap data during combination later (binning hell).
-				//newSpectrum->removeZeroValDataPoints();
-
 				// qDebug() << __FILE__ << __LINE__
 				// << "Allocated new spectrum of " << mzList.size() << "peaks";
 
@@ -967,6 +953,8 @@ namespace msXpSmineXpert
 			// We have finished parsing all the results returned by the database, just
 			// return.
 
+			database.close();
+
 			return newSpectraAllocated;
 		}
 
@@ -996,27 +984,41 @@ namespace msXpSmineXpert
 				QVector<double> *keyVector,
 				QVector<double> *valVector)
 		{
-			if(keyVector == nullptr || valVector == nullptr)
+			if(keyVector == Q_NULLPTR || valVector == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
+			//! Handler of SQLite3-based mass data.
+			//This loader loads data from a SQLite3-based mass spectrometry format and
+			//uses the features of the MassSpecSqlite3Handler class that is required
+			//to craft SQL-based statements to extract data from the database file.
+
+			MassSpecSqlite3Handler sqlite3Handler;
+
 			// And now, make sure the member database, the source database is fine.
 
-			if(!m_sqlite3Handler.initializeDbForRead())
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+			QString connectionName = QString("%1/%2").arg(m_fileName).arg(msXpS::pointerAsString(this));
 
+			QSqlDatabase database = QSqlDatabase::addDatabase("QSQLITE", connectionName);
+			database.setDatabaseName(m_fileName);
+			database.open();
+
+			// Now that we have the database ready initialize the metadata for it.
 			// The initializeDbForRead ensures that m_specMetaData be filled from the
 			// database, so we can check if the data were compressed or not.
 
+			if(!sqlite3Handler.initializeDbForRead(database, true /* readMetaData */))
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
 			bool ok = false;
 			int compressionType;
-			ok = m_sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
+			ok = sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
 
 			if(!ok)
 				compressionType = msXpS::DataCompression::DATA_COMPRESSION_NONE;
 
-			QSqlQuery *sqlQuery = new QSqlQuery(m_sqlite3Handler.m_db);
+			QSqlQuery *sqlQuery = new QSqlQuery(database);
 
-			if(sqlQuery == nullptr)
+			if(sqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			QString srcDbQueryString = craftSqlSelectStatementForStreamedIntegration(history,
@@ -1091,7 +1093,11 @@ namespace msXpSmineXpert
 			// feedback routine.
 			QString msgSkeleton = "Computing streamed rt integration";
 
-			emit setupFeedbackSignal(msgSkeleton, 1, recordCount, -1, LogType::LOG_TO_BOTH);
+			m_progressFeedbackStartValue = 0;
+			m_progressFeedbackEndValue = recordCount;
+
+			emit updateFeedbackSignal(msgSkeleton, -1, true /* setVisible */, LogType::LOG_TO_BOTH,
+					m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 			int fieldNo;
 			int spectraRead = 0;
@@ -1112,6 +1118,8 @@ namespace msXpSmineXpert
 
 			while(sqlQuery->next())
 			{
+				QCoreApplication::processEvents();
+
 				// We do not want to continue doing that work if the user cancelled the
 				// operation.
 				if(m_isOperationCancelled)
@@ -1192,7 +1200,14 @@ namespace msXpSmineXpert
 
 				QString msg = QString(" -- spectrum number %1\n").arg(spectraRead);
 
-				emit updateFeedbackSignal(msgSkeleton + msg, spectraRead, LogType::LOG_TO_STATUS_BAR);
+				emit updateFeedbackSignal(msgSkeleton + msg, spectraRead, true /* setVisible */, LogType::LOG_TO_STATUS_BAR,
+						m_progressFeedbackStartValue, m_progressFeedbackEndValue);
+
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+					"emitting update feedback signal with"
+					<< "start value:" << m_progressFeedbackStartValue
+					<< "end value:" << m_progressFeedbackEndValue
+					<< "current value:" << spectraRead;
 
 				// qDebug() << __FILE__ << __LINE__ << msg;
 			}
@@ -1201,6 +1216,7 @@ namespace msXpSmineXpert
 
 			// Delete the query instance because it holds lots of stuff.
 			delete sqlQuery;
+			database.close();
 
 			// Reset the operation cancelled flag:
 			m_isOperationCancelled = false;
@@ -1239,27 +1255,39 @@ namespace msXpSmineXpert
 				QVector<double> *keyVector,
 				QVector<double> *valVector)
 		{
-			if(keyVector == nullptr || valVector == nullptr)
+			if(keyVector == Q_NULLPTR || valVector == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			// And now, make sure the member database, the source database is fine.
+			//! Handler of SQLite3-based mass data.
+			//This loader loads data from a SQLite3-based mass spectrometry format and
+			//uses the features of the MassSpecSqlite3Handler class that is required
+			//to craft SQL-based statements to extract data from the database file.
 
-			if(!m_sqlite3Handler.initializeDbForRead())
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+			MassSpecSqlite3Handler sqlite3Handler;
 
+			QString connectionName = QString("%1/%2").arg(m_fileName).arg(msXpS::pointerAsString(this));
+
+			QSqlDatabase database = QSqlDatabase::addDatabase("QSQLITE", connectionName);
+			database.setDatabaseName(m_fileName);
+			database.open();
+
+			// Now that we have the database ready initialize the metadata for it.
 			// The initializeDbForRead ensures that m_specMetaData be filled from the
-			// database,
-			// so we can check if the data were compressed or not.
+			// database, so we can check if the data were compressed or not.
+
+			if(!sqlite3Handler.initializeDbForRead(database, true /* readMetaData */))
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
 			bool ok = false;
 			int compressionType;
-			ok = m_sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
+			ok = sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
 
 			if(!ok)
 				compressionType = msXpS::DataCompression::DATA_COMPRESSION_NONE;
 
-			QSqlQuery *sqlQuery = new QSqlQuery(m_sqlite3Handler.m_db);
+			QSqlQuery *sqlQuery = new QSqlQuery(database);
 
-			if(sqlQuery == nullptr)
+			if(sqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			QString srcDbQueryString = craftSqlSelectStatementForStreamedIntegration(history,
@@ -1269,15 +1297,18 @@ namespace msXpSmineXpert
 				qFatal("Fatal error at %s@%d. Program aborted.",
 						__FILE__, __LINE__);
 
+			// qDebug() << __FILE__ << __LINE__
+			// << "For data record counting, the query string is: " << srcDbQueryString;
+
 			ok = sqlQuery->exec(srcDbQueryString);
 
 			if(!ok)
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery->lastError() << "Exiting.\n";
-
-				exit(1);
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery->lastError().text().toLatin1().data());
 			}
 
 			if(!sqlQuery->isActive())
@@ -1298,8 +1329,8 @@ namespace msXpSmineXpert
 			int recordCount =
 				sqlQuery->value(sqlQuery->record().indexOf("COUNT(*)")).toInt();
 
-			// qDebug() << __FILE__ << __LINE__
-			// << "The recordCount:" << recordCount;
+			//qDebug() << __FILE__ << __LINE__
+			//<< "The recordCount:" << recordCount;
 
 			// Now reset the query
 			sqlQuery->finish();
@@ -1309,6 +1340,10 @@ namespace msXpSmineXpert
 			srcDbQueryString = craftSqlSelectStatementForStreamedIntegration(history,
 					false /* with the record COUNT * statement */, false /* integrateToDt */);
 
+			if(srcDbQueryString.isEmpty())
+				qFatal("Fatal error at %s@%d. Program aborted.",
+						__FILE__, __LINE__);
+
 			// qDebug() << __FILE__ << __LINE__
 			// << "For data loading, now, the query string is: " << srcDbQueryString;
 
@@ -1334,11 +1369,14 @@ namespace msXpSmineXpert
 			// feedback routine.
 			QString msgSkeleton = "Computing streamed m/z integration";
 
-			emit setupFeedbackSignal(msgSkeleton, 1, recordCount, -1, LogType::LOG_TO_BOTH);
+			m_progressFeedbackStartValue = 0;
+			m_progressFeedbackEndValue = recordCount;
+
+			emit updateFeedbackSignal(msgSkeleton, 0, true /* setVisible */, LogType::LOG_TO_BOTH,
+					m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 			int fieldNo;
 			int spectraRead = 0;
-
 			msXpSlibmass::MassSpectrum combinedMassSpectrum;
 
 			// I need to comment that out because it crashes the program below.
@@ -1356,6 +1394,8 @@ namespace msXpSmineXpert
 
 			while(sqlQuery->next())
 			{
+				QCoreApplication::processEvents();
+
 				// We do not want to continue doing that work if the user cancelled the
 				// operation.
 				if(m_isOperationCancelled)
@@ -1401,7 +1441,7 @@ namespace msXpSmineXpert
 				delete p_enc64IByteArray;
 
 				// qDebug() << __FILE__ << __LINE__
-				// << "Combined new spectrum of " << newSpectrum->size() << "peaks";
+				// << "Allocated new spectrum of " << newSpectrum->size() << "peaks";
 
 				// We are performing a combination of various mass spectra (the
 				// mp_spectrum contains the spectra that are read from file) into a single
@@ -1440,13 +1480,17 @@ namespace msXpSmineXpert
 
 				QString msg = QString(" -- spectrum number %1\n").arg(spectraRead);
 
-				emit updateFeedbackSignal(msgSkeleton + msg, spectraRead, LogType::LOG_TO_STATUS_BAR);
+				emit updateFeedbackSignal(msgSkeleton + msg, spectraRead, true /* setVisible */, LogType::LOG_TO_STATUS_BAR,
+						m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 				// qDebug() << __FILE__ << __LINE__ << msg;
 			}
+			// End of
+			// while(sqlQuery->next())
 
 			// Delete the query instance because it holds lots of stuff.
 			delete sqlQuery;
+			database.close();
 
 			// We now need to conclude the combination of all the spectra into
 			// m_spectrum and make sure we remove all the zero-val data points if
@@ -1488,30 +1532,45 @@ namespace msXpSmineXpert
 				QVector<double> *keyVector,
 				QVector<double> *valVector)
 		{
-			if(!isDriftExperiment())
+			if(keyVector == Q_NULLPTR || valVector == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			// Create the database connection that we'll need to check if the data are from
+			// an ion mobility mass spectrometry experiment.
+			QString connectionName = QString("%1/%2").arg(m_fileName).arg(msXpS::pointerAsString(this));
+
+			QSqlDatabase database = QSqlDatabase::addDatabase("QSQLITE", connectionName);
+			database.setDatabaseName(m_fileName);
+			database.open();
+
+			//! Handler of SQLite3-based mass data.
+			//This loader loads data from a SQLite3-based mass spectrometry format and
+			//uses the features of the MassSpecSqlite3Handler class that is required
+			//to craft SQL-based statements to extract data from the database file.
+
+			MassSpecSqlite3Handler sqlite3Handler;
+			if(!sqlite3Handler.isDriftExperiment(database))
+			{
 				return -1;
+			}
 
-			if(keyVector == nullptr || valVector == nullptr)
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
-
-			// And now, make sure the member database, the source database is fine.
-
-			if(!m_sqlite3Handler.initializeDbForRead())
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
-
+			// Now that we have the database ready initialize the metadata for it.
 			// The initializeDbForRead ensures that m_specMetaData be filled from the
-			// database,
-			// so we can check if the data were compressed or not.
+			// database, so we can check if the data were compressed or not.
+
+			if(!sqlite3Handler.initializeDbForRead(database, true /* readMetaData */))
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
 			bool ok = false;
 			int compressionType;
-			ok = m_sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
+			ok = sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
 
 			if(!ok)
 				compressionType = msXpS::DataCompression::DATA_COMPRESSION_NONE;
 
-			QSqlQuery *sqlQuery = new QSqlQuery(m_sqlite3Handler.m_db);
+			QSqlQuery *sqlQuery = new QSqlQuery(database);
 
-			if(sqlQuery == nullptr)
+			if(sqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			QString srcDbQueryString = craftSqlSelectStatementForStreamedIntegration(history,
@@ -1550,8 +1609,8 @@ namespace msXpSmineXpert
 			int recordCount =
 				sqlQuery->value(sqlQuery->record().indexOf("COUNT(*)")).toInt();
 
-			// qDebug() << __FILE__ << __LINE__
-			// << "The recordCount:" << recordCount;
+			//qDebug() << __FILE__ << __LINE__
+			//<< "The recordCount:" << recordCount;
 
 			// Now reset the query
 			sqlQuery->finish();
@@ -1565,32 +1624,31 @@ namespace msXpSmineXpert
 				qFatal("Fatal error at %s@%d. Program aborted.",
 						__FILE__, __LINE__);
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__
-				<< "For data loading, now, the query string is: " << srcDbQueryString;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+			//<< "For data loading, now, the query string is: " << srcDbQueryString;
 
 			ok = sqlQuery->exec(srcDbQueryString);
 
 			if(!ok)
-			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery->lastError() << "Exiting.\n";
-
-				exit(1);
-			}
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"The query is not active."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
 
 			if(!sqlQuery->isActive())
-			{
 				qFatal(
-						"Fatal error at %s@%d. The query is not active. Program aborted.",
+						"Fatal error at %s@%d.  Program aborted.",
 						__FILE__, __LINE__);
-			}
 
 			// Before going on with the actual results parsing, let's setup the
 			// feedback routine.
 			QString msgSkeleton = "Computing streamed dt integration";
 
-			emit setupFeedbackSignal(msgSkeleton, 1, recordCount, LogType::LOG_TO_BOTH);
+			m_progressFeedbackStartValue = 0;
+			m_progressFeedbackEndValue = recordCount;
+
+			emit updateFeedbackSignal(msgSkeleton, 0, true /* setVisible */,
+					LogType::LOG_TO_BOTH, m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 			int fieldNo;
 			int spectraRead = 0;
@@ -1612,6 +1670,8 @@ namespace msXpSmineXpert
 
 			while(sqlQuery->next())
 			{
+				QCoreApplication::processEvents();
+
 				// We do not want to continue doing that work if the user cancelled the
 				// operation.
 				if(m_isOperationCancelled)
@@ -1685,13 +1745,18 @@ namespace msXpSmineXpert
 
 				QString msg = QString(" -- spectrum number %1\n").arg(spectraRead);
 
-				emit updateFeedbackSignal(msgSkeleton + msg, spectraRead, LogType::LOG_TO_STATUS_BAR);
+				emit updateFeedbackSignal(msgSkeleton + msg, spectraRead,
+						true /* setVisible */, LogType::LOG_TO_STATUS_BAR,
+						m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 				// qDebug() << __FILE__ << __LINE__ << msg;
 			}
+			// End of
+			// while(sqlQuery->next())
 
 			// Delete the query instance because it holds lots of stuff.
 			delete sqlQuery;
+			database.close();
 
 			// Now actually set the values to the vectors passed as parameter.
 
@@ -1721,7 +1786,6 @@ namespace msXpSmineXpert
 		// Store the mzML filename for the metaData table of the database:
 
 		m_msFileMetaData.setStringItem("fileName", fileName);
-		m_sqlite3Handler.m_dbFileName = fileName;
 	}
 
 
@@ -1790,6 +1854,17 @@ namespace msXpSmineXpert
 		}
 
 
+	// Not documented on purpose.
+	int
+		MassSpecDataFileLoaderSqlite3::readSpectrumCount()
+		{
+			qFatal("Fatal error at %s@%d -- %s(). "
+					"We should never arrive here."
+					"Program aborted.",
+					__FILE__, __LINE__, __FUNCTION__);
+		}
+
+
 	//! Determines from the mass data file the total number of spectra.
 	/*!
 
@@ -1801,12 +1876,13 @@ namespace msXpSmineXpert
 
 */
 	int
-		MassSpecDataFileLoaderSqlite3::readSpectrumCount()
+		MassSpecDataFileLoaderSqlite3::readSpectrumCount(QSqlDatabase &database,
+				MassSpecSqlite3Handler &handler)
 		{
-			if(!m_sqlite3Handler.initializeDbForRead())
+			if(!handler.initializeDbForRead(database))
 				return -1;
 
-			QSqlQuery sqlQuery(m_sqlite3Handler.m_db);
+			QSqlQuery sqlQuery(database);
 			bool ok = false;
 
 			QString queryString("SELECT spectrumListCount from metaData");
@@ -1835,9 +1911,6 @@ namespace msXpSmineXpert
 
 			int count = sqlQuery.value(0).toInt(&ok);
 
-			//qDebug() << __FILE__ << __LINE__
-			//<< "count:" << count;
-
 			if(!ok)
 			{
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -1845,6 +1918,9 @@ namespace msXpSmineXpert
 
 			m_spectrumCount = count;
 
+			//qDebug() << __FILE__ << __LINE__
+			//<< "spectrum count:" << m_spectrumCount;
+
 			return m_spectrumCount;
 		}
 
@@ -1870,9 +1946,12 @@ namespace msXpSmineXpert
 
 */
 	int
-		MassSpecDataFileLoaderSqlite3::loadData(MassSpecDataSet *massSpecDataSet)
+		MassSpecDataFileLoaderSqlite3::loadData(QSqlDatabase &database,
+				MassSpecSqlite3Handler &handler, MassSpecDataSet *massSpecDataSet)
 		{
-			if(massSpecDataSet == nullptr)
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+
+			if(massSpecDataSet == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			// We first try to know if the data in the database are for a
@@ -1880,7 +1959,7 @@ namespace msXpSmineXpert
 			// experiment.
 			int dataKind = MassDataKind::MASS_SPECTRA;
 
-			bool isDriftExp = isDriftExperiment();
+			bool isDriftExp = handler.isDriftExperiment(database);
 
 			if(isDriftExp)
 				dataKind = MassDataKind::DRIFT_SPECTRA;
@@ -1896,18 +1975,28 @@ namespace msXpSmineXpert
 			// spectra in the spectralData table.
 
 			if(m_spectrumCount == -1)
-				readSpectrumCount();
+				readSpectrumCount(database, handler);
 
 			if(m_spectrumCount == -1)
 				qFatal("Fatal error at %s@%d. Program aborted.",
 						__FILE__, __LINE__);
 
+			m_progressFeedbackStartValue = 0;
+			m_progressFeedbackEndValue = m_spectrumCount;
+
 			QString msg = QString("Loading data: total number of spectra to load: %1\n")
 				.arg(m_spectrumCount);
 
-			emit setupFeedbackSignal(msg, 0, m_spectrumCount, -1, LogType::LOG_TO_BOTH);
+			m_progressFeedbackStartValue = 0;
+			m_progressFeedbackEndValue = m_spectrumCount;
 
-			emit dataLoadMessageSignal(msg, LOG_TO_BOTH);
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+				"emitting update feedback signal with"
+				<< "start value:" << m_progressFeedbackStartValue
+				<< "end value:" << m_progressFeedbackEndValue;
+
+			emit updateFeedbackSignal(msg, 0, true /* setVisible */,
+					LogType::LOG_TO_BOTH, m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 			//qDebug() << __FILE__ << __LINE__
 			//<< "Loading data: total number of spectra to load:" << m_spectrumCount;
@@ -1937,13 +2026,18 @@ namespace msXpSmineXpert
 
 				msg = QString("Loading data, spectra %1 to %2\n").arg(iter).arg(lastId);
 
+				emit updateFeedbackSignal(msg, lastId, true /* setVisible */,
+						LogType::LOG_TO_BOTH,
+						m_progressFeedbackStartValue, m_progressFeedbackEndValue);
+
+				// FIXME
 				//emit dataLoadMessageSignal(msg, LOG_TO_BOTH_OVERWRITE);
-				emit dataLoadProgressSignal(lastId);
+				//emit dataLoadProgressSignal(lastId);
 
 				// qDebug() << __FILE__ << __LINE__
 				// << "Loading spectra from " << iter << "to" << lastId;
 
-				loadSpectra(iter, lastId, massSpecDataSet, dataKind);
+				loadSpectra(database, handler, iter, lastId, massSpecDataSet, dataKind);
 
 				iter = lastId + 1;
 				lastId = iter + m_parseProgressionNumber;
@@ -1997,27 +2091,26 @@ namespace msXpSmineXpert
 
 				return -1;
 			}
-			else
-			{
-				qDebug() << __FILE__ << __LINE__
-					<< "history as text:" << history.asText();
-			}
+			//else
+			//{
+			//qDebug() << __FILE__ << __LINE__
+			//<< "history as text:" << history.asText();
+			//}
 
 			//qDebug() << __FILE__ << __LINE__
 			//<< "At this point, the m_fileName:" << m_fileName;
 
 
-			if(integrationType == IntegrationType::XXX_TO_RT)
+			if(integrationType == IntegrationType::ANY_TO_RT)
 				return streamedRtIntegration(history, keyVector, valVector);
-			else if(integrationType == IntegrationType::XXX_TO_MZ)
+			else if(integrationType == IntegrationType::ANY_TO_MZ)
 				return streamedMzIntegration(history, keyVector, valVector);
-			else if(integrationType == IntegrationType::XXX_TO_DT)
+			else if(integrationType == IntegrationType::ANY_TO_DT)
 				return streamedDtIntegration(history, keyVector, valVector);
 			else
 			{
 				qDebug() << __FILE__ << __LINE__ << "No valid integration type is "
-					"defined for the data to be "
-					"produced. Returning.";
+					"defined for the data to be produced. Returning.";
 			}
 
 			return -1;
@@ -2064,24 +2157,36 @@ namespace msXpSmineXpert
 				qFatal("Fatal error at %s@%d. Program aborted.",
 						__FILE__, __LINE__);
 
-			// And now, make sure the member database, the source database is fine.
+			//! Handler of SQLite3-based mass data.
+			//This loader loads data from a SQLite3-based mass spectrometry format and
+			//uses the features of the MassSpecSqlite3Handler class that is required
+			//to craft SQL-based statements to extract data from the database file.
 
-			if(!m_sqlite3Handler.initializeDbForRead())
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+			MassSpecSqlite3Handler sqlite3Handler;
 
+			QString connectionName = QString("%1/%2").arg(m_fileName).arg(msXpS::pointerAsString(this));
+
+			QSqlDatabase database = QSqlDatabase::addDatabase("QSQLITE", connectionName);
+			database.setDatabaseName(m_fileName);
+			database.open();
+
+			// Now that we have the database ready initialize the metadata for it.
 			// The initializeDbForRead ensures that m_specMetaData be filled from the
 			// database, so we can check if the data were compressed or not.
 
+			if(!sqlite3Handler.initializeDbForRead(database, true /* readMetaData */))
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
 			bool ok = false;
 			int compressionType;
-			ok = m_sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
+			ok = sqlite3Handler.m_msFileMetaData.intItem("compressionType", compressionType);
 
 			if(!ok)
 				compressionType = msXpS::DataCompression::DATA_COMPRESSION_NONE;
 
-			QSqlQuery *sqlQuery = new QSqlQuery(m_sqlite3Handler.m_db);
+			QSqlQuery *sqlQuery = new QSqlQuery(database);
 
-			if(sqlQuery == nullptr)
+			if(sqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			QString srcDbQueryString = craftSqlSelectStatementForStreamedIntegration(history,
@@ -2091,16 +2196,18 @@ namespace msXpSmineXpert
 				qFatal("Fatal error at %s@%d. Program aborted.",
 						__FILE__, __LINE__);
 
+			// qDebug() << __FILE__ << __LINE__
+			// << "For data record counting, the query string is: " << srcDbQueryString;
+
 			ok = sqlQuery->exec(srcDbQueryString);
 
 			if(!ok)
 			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery->lastError() << "Exiting.\n";
-
-				qFatal("Fatal error at %s@%d. Program aborted.",
-						__FILE__, __LINE__);
+				qFatal("Fatal error at %s@%d -- %s(). Error: %s."
+						"Failed to get proper data from the database.\n."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__,
+						sqlQuery->lastError().text().toLatin1().data());
 			}
 
 			if(!sqlQuery->isActive())
@@ -2132,20 +2239,20 @@ namespace msXpSmineXpert
 			srcDbQueryString = craftSqlSelectStatementForStreamedIntegration(history,
 					false /* with the record COUNT * statement */, false /* integrateToDt */);
 
+			if(srcDbQueryString.isEmpty())
+				qFatal("Fatal error at %s@%d. Program aborted.",
+						__FILE__, __LINE__);
+
 			// qDebug() << __FILE__ << __LINE__
 			// << "For data loading, now, the query string is: " << srcDbQueryString;
 
 			ok = sqlQuery->exec(srcDbQueryString);
 
 			if(!ok)
-			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Failed to get proper data from the database.\n"
-					<< sqlQuery->lastError() << "Exiting.\n";
-
-				qFatal("Fatal error at %s@%d. Program aborted.",
-						__FILE__, __LINE__);
-			}
+				qFatal("Fatal error at %s@%d -- %s() -- error: %s Exiting. "
+						"Failed to get proper data from the database.\n"
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__, sqlQuery->lastError().text().toLatin1().data());
 
 			if(!sqlQuery->isActive())
 			{
@@ -2156,9 +2263,13 @@ namespace msXpSmineXpert
 
 			// Before going on with the actual results parsing, let's setup the
 			// feedback routine.
-			QString msgSkeleton = "Computing streamed rt integration";
+			QString msgSkeleton = "Computing streamed TIC integration";
 
-			emit setupFeedbackSignal(msgSkeleton, 1, recordCount, -1, LogType::LOG_TO_BOTH);
+			m_progressFeedbackStartValue = 0;
+			m_progressFeedbackEndValue = recordCount;
+
+			emit updateFeedbackSignal(msgSkeleton, 0, true /* setVisible */,
+					LogType::LOG_TO_BOTH, m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 			int fieldNo;
 			int spectraRead = 0;
@@ -2244,13 +2355,16 @@ namespace msXpSmineXpert
 
 				QString msg = QString(" -- spectrum number %1\n").arg(spectraRead);
 
-				emit updateFeedbackSignal(msgSkeleton + msg, spectraRead, LogType::LOG_TO_STATUS_BAR);
+				emit updateFeedbackSignal(msgSkeleton + msg, spectraRead,
+						true /* setVisible */, LogType::LOG_TO_STATUS_BAR,
+						m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 				// qDebug() << __FILE__ << __LINE__ << msg;
 			}
 
 			// Delete the query instance because it holds lots of stuff.
 			delete sqlQuery;
+			database.close();
 
 			// Reset the operation cancelled flag:
 			m_isOperationCancelled = false;
