@@ -262,7 +262,8 @@ namespace msXpSmineXpert
 */
 	bool
 		MassSpecSqlite3Handler::writeDbMassSpecFileMetaData(
-				const MassSpecFileMetaData &specMetaData, QSqlDatabase *db)
+				QSqlDatabase &database,
+				const MassSpecFileMetaData &specMetaData)
 		{
 
 			// QString *text =
@@ -271,13 +272,15 @@ namespace msXpSmineXpert
 			//<< "Getting specMetaData:" << *text;
 			// delete text;
 
-			QSqlQuery *sqlQuery;
+			if(!initializeDbForRead(database))
+			{
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+					<< "Failed to initialize database for read.";
 
-			if(db != Q_NULLPTR)
-				sqlQuery = new QSqlQuery(*db);
-			else
-				sqlQuery = new QSqlQuery(m_db);
+				return false;
+			}
 
+			QSqlQuery *sqlQuery = new QSqlQuery(database);
 			if(sqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
@@ -383,8 +386,8 @@ namespace msXpSmineXpert
 
 */
 	bool
-		MassSpecSqlite3Handler::writeDbDriftData(double driftTime, int driftBin,
-				int *recordId, QSqlDatabase *db)
+		MassSpecSqlite3Handler::writeDbDriftData(QSqlDatabase &database,
+				double driftTime, int driftBin, int *recordId)
 		{
 			if(recordId == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -425,25 +428,7 @@ namespace msXpSmineXpert
 			// << "driftBin: " << driftBin;
 
 
-			QSqlQuery *sqlQuery = Q_NULLPTR;
-
-			if(db != Q_NULLPTR)
-			{
-				// qDebug() << __FILE__ << __LINE__
-				// << "Destination database is not nullptr: " << db
-				// << "with name:" << db->databaseName();
-
-				sqlQuery = new QSqlQuery(*db);
-			}
-			else
-			{
-				// qDebug() << __FILE__ << __LINE__
-				// << "Using member database: "<< &m_db
-				// << "with name:" << m_db.databaseName();
-
-				sqlQuery = new QSqlQuery(m_db);
-			}
-
+			QSqlQuery *sqlQuery = new QSqlQuery(database);
 			if(sqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
@@ -638,33 +623,15 @@ namespace msXpSmineXpert
 
 */
 	bool
-		MassSpecSqlite3Handler::writeDbSpectralData(
+		MassSpecSqlite3Handler::writeDbSpectralData(QSqlDatabase &database,
 				int idx, const QString &title, int peakCount,
 				int msLevel, double tic, double scanStartTime,
 				int driftDataId, double mzStart, double mzEnd,
-				const QByteArray &mzByteArray, const QByteArray &iByteArray,
-				QSqlDatabase *db)
+				const QByteArray &mzByteArray, const QByteArray &iByteArray)
 		{
 			// double start = omp_get_wtime();
 
-			QSqlQuery *sqlQuery = Q_NULLPTR;
-
-			if(db != Q_NULLPTR)
-			{
-				// qDebug() << __FILE__ << __LINE__
-				// << "Using the other database:" << db
-				// << "with name:" << db->databaseName();
-
-				sqlQuery = new QSqlQuery(*db);
-			}
-			else
-			{
-				// qDebug() << __FILE__ << __LINE__
-				// << "Using the member database:" << &m_db
-				// << "with name:" << m_db.databaseName();
-
-				sqlQuery = new QSqlQuery(m_db);
-			}
+			QSqlQuery *sqlQuery = new QSqlQuery(database);
 
 			if(sqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -824,23 +791,16 @@ namespace msXpSmineXpert
 
 */
 	bool
-		MassSpecSqlite3Handler::createDbTables(QSqlDatabase *db)
+		MassSpecSqlite3Handler::createDbTables(QSqlDatabase &database)
 		{
-			QSqlQuery *sqlQuery;
-
-			if(db != Q_NULLPTR)
-				sqlQuery = new QSqlQuery(*db);
-			else
-				sqlQuery = new QSqlQuery(m_db);
+			QSqlQuery *sqlQuery = new QSqlQuery(database);
 
 			if(sqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			// This PRAGMA synchronous call is only really useful when the program runs
-			// on conventional
-			// hard disks, with plates that rotate. In the case of solid state disks,
-			// the
-			// benefits are lower.
+			// This PRAGMA synchronous call is only really useful when the program
+			// runs on conventional hard disks, with plates that rotate. In the case
+			// of solid state disks, the benefits are lower.
 
 			if(!sqlQuery->exec("PRAGMA synchronous = OFF"))
 			{
@@ -925,12 +885,10 @@ namespace msXpSmineXpert
 			}
 
 			if(!createDriftDataTableSpecifs())
-			{
-				qDebug()
-					<< __FILE__ << __LINE__
-					<< "Failed to create the driftData table specifications. Exiting.\n";
-				exit(1);
-			}
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Failed to create the driftData table specifications."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
 
 			// Ask for the sql string that will allow us to create the
 			// table.
@@ -970,20 +928,8 @@ namespace msXpSmineXpert
 		\param fileName name of the file that contains or will contain the database.
 
 */
-	MassSpecSqlite3Handler::MassSpecSqlite3Handler(const QString &fileName)
+	MassSpecSqlite3Handler::MassSpecSqlite3Handler()
 	{
-		if(!fileName.isEmpty())
-		{
-			m_dbFileName = fileName;
-
-			if(!QFile(m_dbFileName).exists())
-				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-					<< "Attention the file does not exist:" << m_dbFileName;
-		}
-		else
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__
-				<< "Filename for the database is empty "
-				"in MassSpecSqlite3Handler constructor.";
 	}
 
 
@@ -993,111 +939,25 @@ namespace msXpSmineXpert
 	}
 
 
-	//! Initialize the \p fileName database file for reading.
-	/*!
-
-		If \p fileName is empty, ensures that the database is open and valid. If \p
-		fileName is not empty, make so that the database is that file and open it
-		and check that it is valid.
-
-		\param fileName name of the database file to be initialized for reading. Can
-		be empty, in which case the \c m_db database is checked for openness and
-		validity.
-
-		\return true if the initialization succeeded, false otherwise.
-
-*/
 	bool
-		MassSpecSqlite3Handler::initializeDbForRead(const QString &fileName)
+		MassSpecSqlite3Handler::initializeDbForRead(QSqlDatabase &database, bool readMetaData)
 		{
-			// We want to initialize the member database (m_db, that is actually a
-			// connection to a database, the QSqlDatabase class instance).
-			//
-			// We can either initialize the database connextion with the member
-			// filename or the one passed as parameter.
+			if(!database.isOpen() || !database.isValid())
+				if(!database.open())
+					return false;
 
-			if(fileName.isEmpty())
-			{
-				// We work on the internal m_db database.
-				//
-				if(m_db.isOpen() && m_db.isValid())
-				{
-					return true;
-				}
-
-				// else
-				// we'll work later on the m_dbFileName.
-			}
-			else
-			{
-				// We need to work on the new database fileName passed as parameter.
-				// But then, if the database connection was already done, we need to
-				// close it first.
-				if(m_db.isOpen() && m_db.isValid())
-					m_db.close();
-
-				m_dbFileName = fileName;
-			}
-
-			// At this point, go on with m_dbFileName.
-
-			if(m_dbFileName.isEmpty())
-			{
-				qDebug() << __FILE__ << __LINE__
-					<< "The member database file name datum is empty\n";
-
-				return false;
-			}
-
-			QFile file(m_dbFileName);
-
-			if(!file.exists())
-			{
-				qDebug() << __FILE__ << __LINE__ << "File" << m_dbFileName
-					<< "was not found.\n";
-
-				return false;
-			}
-
-			// At this point, we know that the database file exists.
-
-			// qDebug() << __FILE__ << __LINE__
-			// << "The database needs to be opened:"
-			// << m_dbFileName
-			// << ".\n";
-
-			m_db = QSqlDatabase::addDatabase("QSQLITE", "MEMBER_DATABASE");
-			m_db.setDatabaseName(m_dbFileName);
-
-			bool ok = false;
-			ok = m_db.open();
-
-			if(!ok)
-			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Opening database: Failure. Exiting.\n";
-
-				return false;
-			}
-			else
-			{
-				// qDebug() << __FILE__ << __LINE__
-				// << "Database successfully opened.\n";
-			}
-
-			// Now initialize the m_msFileMetaData with data from the database:
-			m_msFileMetaData = getMassSpecFileMetaDataFromDb();
-
-			// QString *debugString =
-			// m_msFileMetaData.text(MassSpecFileMetaDataType::MASS_SPEC_META_DATA_TYPE_ALL);
-			// qDebug() << __FILE__ << __LINE__
-			// << "Metadata:" << *debugString << "\n";
-			// delete debugString;
+			// Now initialize the m_msFileMetaData with data from the database (if so
+			// requested)
+			if(readMetaData)
+				m_msFileMetaData = getMassSpecFileMetaDataFromDb(database);
 
 			return true;
 		}
 
 
+
+
+
 	//! Initialize the member database for writing records.
 	/*!
 
@@ -1111,34 +971,22 @@ namespace msXpSmineXpert
 
 */
 	bool
-		MassSpecSqlite3Handler::initializeDbForWrite()
+		MassSpecSqlite3Handler::initializeDbForWrite(QSqlDatabase &database)
 		{
 
-			if(m_db.isOpen())
-				m_db.close();
+			if(!database.isOpen())
+				if(!database.open())
+				{
+					qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+						<< "Failed to open the database.";
 
-			m_db.removeDatabase("MEMBER_DATABASE");
+					return false;
+				}
 
-			m_db = QSqlDatabase::addDatabase("QSQLITE", "MEMBER_DATABASE");
-			m_db.setDatabaseName(m_dbFileName);
+			qWarning() << __FILE__ << __LINE__
+				<< "Database is now open. Now creating the tables.";
 
-			bool ok = false;
-
-			ok = m_db.open();
-
-			if(!ok)
-			{
-				qDebug() << __FILE__ << __LINE__
-					<< "Opening database: Failure. Exiting.\n";
-				exit(1);
-			}
-			else
-			{
-				// qWarning() << __FILE__ << __LINE__
-				// << "Opening database: Success. Now creating the tables.";
-			}
-
-			if(!createDbTables())
+			if(!createDbTables(database))
 			{
 				qFatal("Fatal error at %s@%d -- %s. "
 						"Creating tables: Failure. Exiting.\n"
@@ -1159,25 +1007,12 @@ namespace msXpSmineXpert
 
 	// Set the SQLite3 data file name
 	void
-		MassSpecSqlite3Handler::setFileName(const QString &fileName)
+		MassSpecSqlite3Handler::setDbFileName(const QString &fileName)
 		{
-			// Close the database because this object might be called multiple times
-			// with different file names.
-
-			closeDb();
 			m_dbFileName = fileName;
 		}
 
 
-	//! Close the database and remove the connection.
-	void
-		MassSpecSqlite3Handler::closeDb()
-		{
-			m_db.close();
-			m_db.removeDatabase("MEMBER_DATABASE");
-		}
-
-
 	//! Extract from the database the data in the metaData table.
 	/*!
 
@@ -1186,16 +1021,16 @@ namespace msXpSmineXpert
 
 */
 	MassSpecFileMetaData
-		MassSpecSqlite3Handler::getMassSpecFileMetaDataFromDb()
+		MassSpecSqlite3Handler::getMassSpecFileMetaDataFromDb(QSqlDatabase &database)
 		{
 			// Get the metaData out of the database.
 
 			MassSpecFileMetaData specMetaData;
 
-			if(!initializeDbForRead())
+			if(!initializeDbForRead(database))
 				return specMetaData;
 
-			QSqlQuery sqlQuery(m_db);
+			QSqlQuery sqlQuery(database);
 			bool ok = false;
 
 			QString queryString("SELECT * FROM metaData");
@@ -1252,12 +1087,12 @@ namespace msXpSmineXpert
 
 */
 	int
-		MassSpecSqlite3Handler::spectrumListCount()
+		MassSpecSqlite3Handler::spectrumListCount(QSqlDatabase &database)
 		{
-			if(!initializeDbForRead())
+			if(!initializeDbForRead(database))
 				return -1;
 
-			QSqlQuery sqlQuery(m_db);
+			QSqlQuery sqlQuery(database);
 			bool ok = false;
 
 			QString queryString("SELECT spectrumListCount from metaData");
@@ -1309,11 +1144,11 @@ namespace msXpSmineXpert
 
 */
 	QList<double>
-		MassSpecSqlite3Handler::rtList()
+		MassSpecSqlite3Handler::rtList(QSqlDatabase &database)
 		{
 			QList<double> rtList;
 
-			if(!initializeDbForRead())
+			if(!initializeDbForRead(database))
 			{
 				qDebug() << __FILE__ << __LINE__
 					<< "Failed to initialize the database for read.";
@@ -1321,7 +1156,7 @@ namespace msXpSmineXpert
 				return rtList;
 			}
 
-			QSqlQuery sqlQuery(m_db);
+			QSqlQuery sqlQuery(database);
 			bool ok = false;
 
 			QString queryString("SELECT scanStartTime from spectralData "
@@ -1371,14 +1206,14 @@ namespace msXpSmineXpert
 
 */
 	void
-		MassSpecSqlite3Handler::mzRange(double &mzStart, double &mzEnd)
+		MassSpecSqlite3Handler::mzRange(QSqlDatabase &database, double &mzStart, double &mzEnd)
 		{
 			// We need to get the first and the last mz values of the spectrum.
 
-			if(!initializeDbForRead())
+			if(!initializeDbForRead(database))
 				return;
 
-			QSqlQuery sqlQuery(m_db);
+			QSqlQuery sqlQuery(database);
 			bool ok = false;
 
 			QString queryString("SELECT mzStart,mzEnd from spectralData");
@@ -1433,16 +1268,16 @@ namespace msXpSmineXpert
 
 */
 	bool
-		MassSpecSqlite3Handler::isDriftExperiment()
+		MassSpecSqlite3Handler::isDriftExperiment(QSqlDatabase &database)
 		{
 			// By asking the database to tell us if it has a value for
 			// driftBinCount in the metaData table we'll know if this database is
 			// for a mobility drift time experiment.
 
-			if(!initializeDbForRead())
+			if(!initializeDbForRead(database, false /* readMetaData */))
 				return -1;
 
-			QSqlQuery sqlQuery(m_db);
+			QSqlQuery sqlQuery(database);
 			bool ok = false;
 
 			QString queryString("SELECT driftBinCount from metaData");
@@ -1491,12 +1326,12 @@ namespace msXpSmineXpert
 
 */
 	QList<double> *
-		MassSpecSqlite3Handler::driftTimeList()
+		MassSpecSqlite3Handler::driftTimeList(QSqlDatabase &database)
 		{
-			if(!initializeDbForRead())
+			if(!initializeDbForRead(database))
 				return 0;
 
-			QSqlQuery sqlQuery(m_db);
+			QSqlQuery sqlQuery(database);
 			bool ok = false;
 
 			QString queryString("SELECT * FROM driftData");
@@ -1564,27 +1399,16 @@ namespace msXpSmineXpert
 
 */
 	bool
-		MassSpecSqlite3Handler::exportData_metaData(QSqlDatabase *db,
+		MassSpecSqlite3Handler::exportData_metaData(QSqlDatabase &srcDatabase, QSqlDatabase &dstDatabase,
 				int spectrumListCount)
 		{
-			if(db == Q_NULLPTR)
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
-
-			// else
-			// qDebug() << __FILE__ << __LINE__
-			// << "The destination database has pointer: " << db
-			// << "and name:" << db->databaseName();
 
 			QString srcDbQueryString = "SELECT * FROM metaData";
 
-			// The member database is the source database while db points to the
-			// destination database, that was opened with connection name
-			// "EXPORT_DESTINATIION".
-
-			if(!initializeDbForRead())
+			if(!initializeDbForRead(srcDatabase))
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			QSqlQuery *srcSqlQuery = new QSqlQuery(m_db);
+			QSqlQuery *srcSqlQuery = new QSqlQuery(srcDatabase);
 
 			if(srcSqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -1667,7 +1491,7 @@ namespace msXpSmineXpert
 
 				metaData.setIntItem("spectrumListCount", spectrumListCount);
 
-				if(!writeDbMassSpecFileMetaData(metaData, db))
+				if(!writeDbMassSpecFileMetaData(dstDatabase, metaData))
 					qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 			}
 
@@ -1691,24 +1515,13 @@ namespace msXpSmineXpert
 
 */
 	bool
-		MassSpecSqlite3Handler::exportData_driftData(QSqlDatabase *db)
+		MassSpecSqlite3Handler::exportData_driftData(QSqlDatabase &srcDatabase, QSqlDatabase &dstDatabase)
 		{
-			if(db == Q_NULLPTR)
+
+			if(!initializeDbForRead(srcDatabase))
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			// else
-			// qDebug() << __FILE__ << __LINE__
-			// << "The destination database has pointer: " << db
-			// << "and name:" << db->databaseName();
-
-			// The member database is the source database while db points to the
-			// destination database, that was opened with connection name
-			// "EXPORT_DESTINATIION".
-
-			if(!initializeDbForRead())
-				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
-
-			QSqlQuery *srcSqlQuery = new QSqlQuery(m_db);
+			QSqlQuery *srcSqlQuery = new QSqlQuery(srcDatabase);
 
 			if(srcSqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -1750,7 +1563,7 @@ namespace msXpSmineXpert
 
 				int recordId;
 
-				if(!writeDbDriftData(driftTime, driftBin, &recordId, db))
+				if(!writeDbDriftData(dstDatabase, driftTime, driftBin, &recordId))
 					qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 			}
 
@@ -1782,7 +1595,7 @@ namespace msXpSmineXpert
 
 */
 	QString
-		MassSpecSqlite3Handler::exportData(QString fileName, History history)
+		MassSpecSqlite3Handler::exportData(QSqlDatabase &srcDatabase, QString dstFileName, History history)
 		{
 			QString errors;
 
@@ -1795,13 +1608,18 @@ namespace msXpSmineXpert
 			// prepare (create it on the basis of the fileName param and create its
 			// tables).
 
-			QSqlDatabase destDb =
-				QSqlDatabase::addDatabase("QSQLITE", "EXPORT_DESTINATION");
-			destDb.setDatabaseName(fileName);
+			QString connectionName = QString("%1/%2")
+				.arg(dstFileName)
+				.arg(msXpS::pointerAsString(this));
+
+			QSqlDatabase dstDatabase =
+				QSqlDatabase::addDatabase("QSQLITE", connectionName);
+
+			dstDatabase.setDatabaseName(dstFileName);
 
 			bool ok = false;
 
-			ok = destDb.open();
+			ok = dstDatabase.open();
 
 			if(!ok)
 			{
@@ -1820,7 +1638,7 @@ namespace msXpSmineXpert
 					"the tables.";
 			}
 
-			if(!createDbTables(&destDb))
+			if(!createDbTables(dstDatabase))
 			{
 				errors += QString("%1 %2 %3 %4")
 					.arg(__FILE__)
@@ -1872,14 +1690,14 @@ namespace msXpSmineXpert
 			// We need to craft a SqlQuery string that is specific of the experimental
 			// situation: are we dealing with drift data or not.
 
-			bool wasDriftExperiment = isDriftExperiment();
+			bool wasDriftExperiment = isDriftExperiment(srcDatabase);
 
 			qDebug() << __FILE__ << __LINE__
 				<< "wasDriftExperiment: " << wasDriftExperiment;
 
 			if(wasDriftExperiment)
 			{
-				if(!exportData_driftData(&destDb))
+				if(!exportData_driftData(srcDatabase, dstDatabase))
 					qFatal("Fatal error at %s@%d. Failed to export the driftData table. "
 							"Program aborted.",
 							__FILE__, __LINE__);
@@ -1989,10 +1807,10 @@ namespace msXpSmineXpert
 
 			// And now, make sure the member database, the source database is fine.
 
-			if(!initializeDbForRead())
+			if(!initializeDbForRead(srcDatabase))
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			QSqlQuery *srcSqlQuery = new QSqlQuery(m_db);
+			QSqlQuery *srcSqlQuery = new QSqlQuery(srcDatabase);
 
 			if(srcSqlQuery == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -2092,7 +1910,12 @@ namespace msXpSmineXpert
 
 			// Before going on with the actual results parsing, let's setup the
 			// feedback routine.
-			emit setupFeedbackSignal("Exporting data", 1, recordCount, -1, LogType::LOG_TO_BOTH);
+			m_progressFeedbackStartValue = 0;
+			m_progressFeedbackEndValue = recordCount;
+
+			emit updateFeedbackSignal("Exporting data", 0, true /* setVisible */,
+					LogType::LOG_TO_BOTH,
+					m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 			// Set some room for all the variables:
 
@@ -2121,7 +1944,9 @@ namespace msXpSmineXpert
 			{
 				++iteration;
 
-				emit updateFeedbackSignal("Exporting data...", iteration, LogType::LOG_TO_STATUS_BAR);
+			emit updateFeedbackSignal("Exporting data", iteration, true /* setVisible */,
+					LogType::LOG_TO_BOTH,
+					m_progressFeedbackStartValue, m_progressFeedbackEndValue);
 
 				// qDebug() << __FILE__ << __LINE__
 				// << "updateFeedbackSignal: Exporting data..." << iteration;
@@ -2194,10 +2019,10 @@ namespace msXpSmineXpert
 				// We now have all the data bits required to actually write the data to
 				// the spectralData table of the destination database.
 
-				if(!writeDbSpectralData(idx, title, peakCount, msLevel, tic,
+				if(!writeDbSpectralData(dstDatabase, idx, title, peakCount, msLevel, tic,
 							scanStartTime, driftData_id,
 							mzStart, mzEnd, mzByteArray,
-							iByteArray, &destDb))
+							iByteArray))
 				{
 					errors += QString("%1 %2 %3 %4")
 						.arg(__FILE__)
@@ -2217,7 +2042,7 @@ namespace msXpSmineXpert
 			delete srcSqlQuery;
 
 			// Finally, we can export the metaData stuff:
-			if(!exportData_metaData(&destDb, spectrumListCount))
+			if(!exportData_metaData(srcDatabase, dstDatabase, spectrumListCount))
 			{
 				errors += QString("%1 %2 %3 %4")
 					.arg(__FILE__)
@@ -2228,11 +2053,81 @@ namespace msXpSmineXpert
 				return errors;
 			}
 			// And now close the destination database.
-			destDb.close();
+			srcDatabase.close();
+			dstDatabase.close();
 
 			return errors;
 		}
 
 
+	//! Export data from \c this \c m_db to a database in file \p fileName.
+	/*!
+
+		The criteria on which data are selected from \c this \c m_db database are
+		described in \p history.  This function uses a number of helper functions to
+		write the data in the various tables of the destination database file (See
+		also section).
+
+		\param fileName name of the destination database.
+
+		\param history History instance describing the criteria for data selection
+		in \c this \m_db database (source database).
+
+		\return true if the operation succeeded. Failure to create tables in the
+		destination database or to write data to the destination database crash the
+		program.
+
+		\sa writeDbMassSpecFileMetaData() <br> writeDbDriftData() <br>
+		writeDbSpectralData()
+
+*/
+	QString
+		MassSpecSqlite3Handler::exportData(QString srcFileName, QString dstFileName, History history)
+		{
+			QString errors;
+
+			// This is a huge task. We need to read data from m_dbFileName (that we
+			// know from the constructor. m_dbFileName is the name of the database
+			// that we call the source. But we get a fileName for the destination
+			// database.
+
+			// First handle the cas of the destination database that we need to
+			// prepare (create it on the basis of the fileName param and create its
+			// tables).
+
+			QString connectionName = QString("%1/%2")
+				.arg(srcFileName)
+				.arg(msXpS::pointerAsString(this));
+
+			QSqlDatabase srcDatabase =
+				QSqlDatabase::addDatabase("QSQLITE", connectionName);
+
+			srcDatabase.setDatabaseName(dstFileName);
+
+			bool ok = false;
+
+			ok = srcDatabase.open();
+
+			if(!ok)
+			{
+				errors += QString("%1 %2 %3 %4")
+					.arg(__FILE__)
+					.arg(__LINE__)
+					.arg(__FUNCTION__)
+					.arg("Opening data export source database: Failure\n");
+
+				return errors;
+			}
+			else
+			{
+				qDebug() << __FILE__ << __LINE__ << "Opening data export source "
+					"database: Success. Now creating the tables.";
+			}
+
+			return exportData(srcDatabase, dstFileName, history);
+		}
+
+
+
 } // namespace msXpSmineXpert
 
