@@ -53,6 +53,8 @@
 namespace msXpSmineXpert
 {
 
+class AbstractPlotWidget;
+
 
 	//! The MassSpecSqlite3Handler class provides a SQLite3 database handler.
 	/*!
@@ -84,9 +86,6 @@ namespace msXpSmineXpert
 		//! The name of the database file.
 		QString m_dbFileName;
 
-		//! The database instance.
-		QSqlDatabase m_db;
-
 		//! Metadata to use for fill-in the metaData table.
 		/*!
 
@@ -108,6 +107,9 @@ namespace msXpSmineXpert
 */
 		int m_parseProgressionNumber = 100;
 
+		int m_progressFeedbackStartValue = -1;
+		int m_progressFeedbackEndValue = -1;
+
 		//! Specifications to create the metaData table.
 		SqlTableSpecifs m_metaDataTableSpecifs;
 
@@ -119,62 +121,59 @@ namespace msXpSmineXpert
 
 
 		bool createMetaDataTableSpecifs();
-		QString
-			metaDataTableInsertSqlCommand(const MassSpecFileMetaData &specMetaData);
-		bool writeDbMassSpecFileMetaData(const MassSpecFileMetaData &specMetaData,
-				QSqlDatabase *db = nullptr);
-
+		QString metaDataTableInsertSqlCommand(const MassSpecFileMetaData &specMetaData);
+		bool writeDbMassSpecFileMetaData(QSqlDatabase &database,
+				const MassSpecFileMetaData &specMetaData);
 
 		bool createDriftDataTableSpecifs();
-		bool writeDbDriftData(double driftTime, int driftBin, int *recordId,
-				QSqlDatabase *db = nullptr);
+		bool writeDbDriftData(QSqlDatabase &database,
+				double driftTime, int driftBin, int *recordId);
 
 		bool createSpectralDataTableSpecifs();
-		bool writeDbSpectralData(int idx, const QString &title, int peakCount,
+		bool writeDbSpectralData(QSqlDatabase &database,
+				int idx, const QString &title, int peakCount,
 				int msLevel, double tic, double scanStartTime,
 				int driftDataId, double mzStart, double mzEnd,
 				const QByteArray &mzByteArray,
-				const QByteArray &iByteArray,
-				QSqlDatabase *db = nullptr);
+				const QByteArray &iByteArray);
 
 		QString tableCreationSqlCommand(QString tableName);
-		bool createDbTables(QSqlDatabase *db = nullptr);
+		bool createDbTables(QSqlDatabase &databse);
 
 
 		public:
 
-		MassSpecSqlite3Handler(const QString &fileName = QString());
+		MassSpecSqlite3Handler();
 		~MassSpecSqlite3Handler();
 
-		bool initializeDbForRead(const QString &fileName = QString());
-		bool initializeDbForWrite();
+		bool initializeDbForRead(QSqlDatabase &database, bool readMetaData = false);
+		bool initializeDbForWrite(QSqlDatabase &database);
 
-		void setFileName(const QString &fileName);
+		void setDbFileName(const QString &fileName);
 
-		void closeDb();
+		MassSpecFileMetaData getMassSpecFileMetaDataFromDb(QSqlDatabase &database);
 
-		MassSpecFileMetaData getMassSpecFileMetaDataFromDb();
+		int spectrumListCount(QSqlDatabase &database);
 
-		int spectrumListCount();
+		QList<double> rtList(QSqlDatabase &database);
 
-		QList<double> rtList();
+		void mzRange(QSqlDatabase &database, double &mzStart, double &mzEnd);
 
-		void mzRange(double &mzStart, double &mzEnd);
+		bool isDriftExperiment(QSqlDatabase &database);
+		QList<double> *driftTimeList(QSqlDatabase &database);
 
-		bool isDriftExperiment();
-		QList<double> *driftTimeList();
+		bool exportData_metaData(QSqlDatabase &srcDatabase, QSqlDatabase &dstDatabase, int spectrumListCount);
+		bool exportData_driftData(QSqlDatabase &srcDatabase, QSqlDatabase &dstDatabase);
+		QString exportData(QSqlDatabase &srcDatabase, QString dstFileName, History history);
+		QString exportData(QString srcFileName, QString dstFileName, History history);
 
-		bool exportData_metaData(QSqlDatabase *db, int spectrumListCount);
-		bool exportData_driftData(QSqlDatabase *db);
-		QString exportData(QString fileName, History history);
 
 signals:
 		void dataLoadMessageSignal(QString msg, int logType);
 		void dataLoadProgressSignal(int spectrumIndex);
 
-		void setupFeedbackSignal(QString msg, int startValue, int endValue,
-				int currentValue, int logType);
-		void updateFeedbackSignal(QString msg, int currentValue, int logType);
+		void updateFeedbackSignal(QString msg, int currentValue,
+				bool setVisible, int logType, int startValue = -1, int endValue = -1);
 	};
 
 }
