@@ -816,8 +816,7 @@ namespace msXpSmineXpert
 				qDebug() << __FILE__ << __LINE__ << __FUNCTION__
 					<< "m_history as transmitted to the sql handler:" << m_history.asText();
 
-				mp_sqlHandler->setFileName(m_srcFileName);
-				errors = mp_sqlHandler->exportData(sliceSpecif->fileName, m_history);
+				errors = mp_sqlHandler->exportData(m_srcFileName, sliceSpecif->fileName, m_history);
 
 				// If there were errors, then return immediately.
 				if(!errors.isEmpty())
